<?php

  $page_id = Params::getParam('pageId');
  $page_id = ($page_id > 0 ? $page_id : 1);
  $per_page = frm_param('topics_per_page');

  $limit = array($per_page, $page_id);

  $board_id = Params::getParam('boardId');
  $board = ModelFRM::newInstance()->getBoard($board_id);

  if(!isset($board['pk_i_id']) || $board['pk_i_id'] <= 0) {
    osc_add_flash_error_message(__('This board does not exists anymore', 'forums'));

    header('Location:' . osc_route_url('frm-home'));
    exit;
  }

  ModelFRM::newInstance()->updateBoardRead(osc_logged_user_id(), $board_id);


  $subboards = ModelFRM::newInstance()->getBoards($board['fk_i_category_id'], $board_id);
  $topics = ModelFRM::newInstance()->getTopics($board_id, $limit);
?>


<div id="frm-body" class="frm-body frm-theme-<?php echo osc_current_web_theme(); ?>">
  <div id="frm-main">
    <div class="frm-content">
      <?php echo frm_breadcrumbs(); ?>

      <div class="frm-title-left">
        <h1><?php echo frm_name($board); ?></h1>

        <?php if(frm_description($board) <> '') { ?>
          <h2><?php echo frm_description($board); ?></h2>
        <?php } ?>
      </div>

      <div class="frm-title-right">
        <?php if(osc_is_web_user_logged_in() && frm_control_user(osc_logged_user_id(), $board)) { ?>
          <a href="<?php echo osc_route_url('frm-new-topic', array('boardId' => $board_id)); ?>" class="frm-new-topic"><?php _e('Create a new topic', 'forums'); ?></a>
        <?php } ?>
      </div>


      <?php if(!frm_control_user(osc_logged_user_id(), $board)) { ?>

        <div class="frm-answer frm-empty">

          <div class="frm-unlogged-title"><?php _e('This board is available only for premium members', 'forums'); ?></div>
          <div class="frm-unlogged-subtitle">
            <?php _e('You have to be member of one of following groups to have access there:', 'forums'); ?>
            <strong><?php echo frm_board_groups($board); ?></strong>
          </div>

          <div class="frm-auth-buttons">
            <a class="frm-auth" href="<?php echo osc_route_url('osp-membership'); ?>"><?php _e('Become Premium Member', 'forums'); ?></a>
          </div>
        </div>

      <?php } else { ?>

        <!-- SUB-BOARDS SECTION -->
        <?php if(count($subboards) > 0) { ?>
          <div class="frm-box">
            <div class="frm-category">
              <div class="frm-c-name"><?php _e('Subforums', 'forums'); ?></div>
            </div>

            <div class="frm-boards">
              <?php foreach($subboards as $subboard) { ?>
                <div class="frm-board<?php if($subboard['i_viewed'] == 0 && osc_is_web_user_logged_in()) { ?> frm-unread<?php } ?>">
                  <div class="frm-icon">
                    <div class="frm-icon-outer">
                      <i class="fa fa-comments"></i>
                    </div>
                  </div>

                  <div class="frm-about">
                    <div class="frm-name"><a href="<?php echo frm_board_url($subboard); ?>"><?php echo frm_name($subboard); ?></a></div>

                    <?php if(isset($subboard['children']) && count($subboard['children']) > 0) { ?>
                      <div class="frm-subboards">
                        <div class="frm-square"></div>

                        <?php foreach($subboard['children'] as $sub_subboard) { ?>
                          <a href="<?php echo frm_board_url($sub_subboard); ?>"><?php echo frm_name($sub_subboard); ?></a>
                        <?php } ?>
                      </div>
                    <?php } ?>

                    <div class="frm-desc"><?php echo frm_description($subboard); ?></div>
                  </div>

                  <div class="frm-stats">
                    <strong><?php echo $subboard['i_num_topics']; ?></strong>
                    <span><?php echo ($subboard['i_num_topics'] == 1 ? __('topic', 'forums') : __('topics', 'forums')); ?></span>
                  </div>

                  <div class="frm-last">
                    <?php if($subboard['fk_i_last_topic_id'] > 0) { ?>
                      <?php
                        $last_topic = ModelFRM::newInstance()->getTopic($subboard['fk_i_last_topic_id']);
                        $last_user = ModelFRM::newInstance()->getUser($subboard['fk_i_last_user_id']);
                        $last_user_img = frm_user_img($last_user);
                      ?>

                      <?php if(isset($last_topic['pk_i_id'])) { ?>
                        <div class="frm-user-icon"><img src="<?php echo $last_user_img; ?>" /></div>
                        <div class="frm-last-topic">
                          <div class="frm-last-title"><a href="<?php echo frm_topic_url($last_topic); ?>"><?php echo osc_highlight($last_topic['s_title'], 40); ?></a></div>
                          <div class="frm-last-user"><?php _e('By', 'forums'); ?> <a href="<?php echo frm_user_url($last_user); ?>"><?php echo frm_user_name($last_user); ?></a></div>
                          <div class="frm-last-date"><?php echo date('j. M Y', strtotime($last_topic['dt_last_post_date'])); ?></div>
                        </div>
                      <?php } ?>
                    <?php } ?>
                  </div>
                </div>
              <?php } ?>
            </div>
          </div>
        <?php } ?>


        <!-- TOPICS SECTION -->
        <div class="frm-topics<?php if(count($topics) <= 0) { ?> frm-empty<?php } ?>">
          <?php if(count($topics) > 0) { ?>

            <?php echo frm_paginate($board, array(), '', 'board', $page_id, $per_page, $board['i_num_topics'], 'frm-pagination-top'); ?>

            <?php foreach($topics as $topic) { ?>
              <?php
                $submitter = ModelFRM::newInstance()->getUser($topic['fk_i_user_id']);
                $last_user = ModelFRM::newInstance()->getUser($topic['fk_i_last_user_id']);
                $last_user_img = frm_user_img($last_user);
              ?>

              <div class="frm-topic<?php if($topic['i_viewed'] == 0 && osc_is_web_user_logged_in()) { ?> frm-unread<?php } ?><?php if(osc_is_web_user_logged_in()) { ?> frm-logged<?php } ?>">
                <?php if($topic['i_viewed'] == 0 && osc_is_web_user_logged_in()) { ?>
                  <i class="fa fa-circle frm-unread-dot frm-has-tooltip-left" title="<?php echo osc_esc_html(__('There are unread comments', 'forums')); ?>"></i>
                <?php } ?>

                <div class="frm-info">
                  <div class="frm-data">
                    <?php if($topic['b_sticky'] == 1) { ?>
                      <i class="fa fa-thumb-tack frm-sticky frm-has-tooltip-left" title="<?php echo osc_esc_html(__('Topic is sticked to top', 'forums')); ?>"></i>
                    <?php } ?>

                    <?php if($topic['b_locked'] == 1) { ?>
                      <i class="fa fa-lock frm-locked frm-has-tooltip-left" title="<?php echo osc_esc_html(__('Topic is locked', 'forums')); ?>"></i>
                    <?php } ?>

                    <?php if($topic['b_solved'] == 1) { ?>
                      <i class="fa fa-lightbulb-o frm-solved frm-has-tooltip-left" title="<?php echo osc_esc_html(__('Topic has been marked as solved', 'forums')); ?>"></i>
                    <?php } ?>
     
                    <a href="<?php echo frm_topic_url($topic); ?>"><?php echo osc_highlight($topic['s_title'], 90); ?></a>
                  </div>

                  <div class="frm-description">
                    <span><?php _e('By', 'forums'); ?></span>
                    <a href="<?php echo frm_user_url($submitter); ?>"><?php echo frm_user_name($submitter); ?></a>
                    <span><?php _e('on', 'forums'); ?></span>
                    <span><?php echo date('j. M Y', strtotime($topic['dt_created'])); ?></span>
                  </div>

                </div>

                <div class="frm-block">
                  <div class="frm-auser">
                    <?php if($topic['s_active_users_ids'] <> '') { ?>
                      <?php 
                        $au_ids = implode(',', array_unique(array_filter(array_map('trim', explode(',', $topic['s_active_users_ids'])))));
                        $active_users = ModelFRM::newInstance()->getUsers($au_ids); 
                      ?>

                      <?php if(count($active_users) > 0) { ?>
                        <?php foreach($active_users as $au) { ?>
                          <?php $atitle = frm_user_name($au) . '<br/>' . (sprintf(__('%s topics created', 'forums'), ($au['i_num_topics'] > 0 ? $au['i_num_topics'] : 0))) . '<br/>' . (sprintf(__('%s posts submitted', 'forums'), ($au['i_num_posts'] > 0 ? $au['i_num_posts'] : 0))) . '<br/>' . (sprintf(__('Joined on %s', 'forums'), date('j. M Y', strtotime($au['dt_registered'])))); ?>

                          <div class="frm-one-user frm-has-tooltip" title="<?php echo $atitle; ?>">
                            <img src="<?php echo frm_user_img($au); ?>"/>
                          </div>
                        <?php } ?>
                      <?php } ?>

                    <?php } ?>
                  </div>

                  <?php echo frm_paginate($board, $topic, '', 'topic', 1, 10, $topic['i_num_posts'], 'frm-apagi'); ?>
                </div>


                <div class="frm-stats">
                  <strong><?php echo $topic['i_num_posts'] . ' ' . ($topic['i_num_posts'] == 1 ? __('reply', 'forums') : __('replies', 'forums')); ?></strong>
                  <span><?php echo @$topic['i_num_views'] . ' ' . (@$topic['i_num_views'] == 1 ? __('view', 'forums') : __('views', 'forums')); ?></span>
                </div>

                <div class="frm-last">
                  <div class="frm-user-icon"><img src="<?php echo $last_user_img; ?>" /></div>
                  <div class="frm-last-topic">
                    <div class="frm-last-user"><a href="<?php echo frm_user_url($last_user); ?>"><?php echo frm_user_name($last_user); ?></a></div>
                    <div class="frm-last-date"><?php echo date('j. M Y', strtotime($topic['dt_last_post_date'])); ?></div>
                  </div>
                </div>
   
              </div>
            <?php } ?>  

            <?php echo frm_paginate($board, array(), '', 'board', $page_id, $per_page, $board['i_num_topics'], 'frm-pagination-bottom'); ?>

          <?php } else { ?>

            <div class="frm-answer<?php if(!osc_is_web_user_logged_in()) { ?> frm-unlogged<?php } ?> frm-empty">

              <?php if(!osc_is_web_user_logged_in()) { ?>
                <div class="frm-unlogged-title"><?php _e('There are no topics yet', 'forums'); ?></div>
                <div class="frm-unlogged-subtitle"><?php _e('Please login or register to create topic, only logged in users can create a new topic.', 'forums'); ?></div>

                <div class="frm-auth-buttons">
                  <a class="frm-auth" href="<?php echo osc_user_login_url(); ?>"><?php _e('Login', 'forums'); ?></a>
                  <a class="frm-auth" href="<?php echo osc_register_account_url(); ?>"><?php _e('Register', 'forums'); ?></a>
                </div>

              <?php } else { ?>
   
                <div class="frm-unlogged-title"><?php _e('There are no topics yet', 'forums'); ?></div>
                <div class="frm-unlogged-subtitle"><?php _e('Be first to create topic in this board', 'forums'); ?></div>

                <div class="frm-auth-buttons">
                  <a class="frm-auth" href="<?php echo osc_route_url('frm-new-topic', array('boardId' => $board_id)); ?>"><?php _e('Create a new topic', 'forums'); ?></a>
                </div>

              <?php } ?>
            </div>


          <?php } ?>
        </div>

      <?php } ?>

    </div>
  </div>
</div>