<?php
  if(Params::getParam('searchWord') <> '') {
    header('Location:' . osc_route_url('frm-search', array('searchTerm' => Params::getParam('searchWord'))));
    exit;
  }

  $term = urldecode(Params::getParam('searchTerm'));
  $term_filled = true;

  if($term <> '') {
    $page_id = Params::getParam('pageId');
    $page_id = ($page_id > 0 ? $page_id : 1);
    $per_page = frm_param('posts_per_page');

    $limit = array($per_page, $page_id);

    $posts = ModelFRM::newInstance()->getPostsBySearchTerm($term, $limit);
    $count = ModelFRM::newInstance()->countPostsBySearchTerm($term);

  } else {
    $posts = array();
    $term_filled = false;
  }

  if(osc_is_web_user_logged_in()) {
    $logged = ModelFRM::newInstance()->getUser(osc_logged_user_id());
  } else {
    $logged = false;
  }
?>


<div id="frm-body" class="frm-body frm-theme-<?php echo osc_current_web_theme(); ?>">
  <div id="frm-main">
    <div class="frm-content">
      <?php echo frm_breadcrumbs(); ?>

      <div class="frm-title-left">
        <?php if($term <> '') { ?>
          <h1><?php echo sprintf(__('Search for %s', 'forums'), '<strong>' . $term . '</strong>'); ?></h1>
        <?php } else { ?>
          <h1><?php echo __('Search', 'forums'); ?></h1>
        <?php } ?>

        <h2><?php _e('All posts those contains search term', 'forums'); ?></h2>
      </div>

      <div class="frm-title-right">
        <form action="<?php echo osc_route_url('frm-search-pre'); ?>" method="POST" class="nocsrf">
          <input type="hidden" name="frmAction" value="search" />
          <input type="text" name="searchWord" value="<?php echo $term; ?>" id="frm-keyword" placeholder="<?php echo osc_esc_html(__('Keyword', 'forums')); ?>" />
          <button type="submit"><i class="fa fa-search"></i></button>
        </form>
      </div>

      <!-- TOP PAGINATION -->
      <?php if(count($posts) > 0 && $term_filled) { ?>
        <?php echo frm_paginate('', '', '', 'search', $page_id, $per_page, $count, 'frm-pagination-topic'); ?>
      <?php } ?>

      <div class="frm-posts">
        <?php 
          if(count($posts) > 0 && $term_filled) {
            foreach($posts as $post) {
              $board = ModelFRM::newInstance()->getBoard($post['fk_i_board_id']);
              $topic = ModelFRM::newInstance()->getTopic($post['fk_i_topic_id']);

              // Check if user can see this topic
              if(frm_control_user(osc_logged_user_id(), $board)) {
                frm_generate_post($board, $topic, $post, 0, 'search', array(), $logged);
              } else {
                ?>
                <div class="frm-post frm-restricted">
                  <div class="frm-row"><?php echo _e('This board is available only to premium members', 'forums'); ?></div>
                  <div class="frm-row"><?php _e('You have to be member of one of following groups to have access there:', 'forums'); ?> <strong><?php echo frm_board_groups($board); ?></strong></div>
                </div>
                <?php
              }
            }
          } else {
            ?>

            <div class="frm-answer frm-search-empty">
              <?php if(!$term_filled) { ?>
                <div class="frm-unlogged-title"><?php _e('Please enter keyword you want to search', 'forums'); ?></div>
                <div class="frm-unlogged-subtitle"><?php _e('To initiate search you must enter keyword', 'forums'); ?></div>
              <?php } else { ?>
                <div class="frm-unlogged-title"><?php _e('There are no posts matching your search criteria', 'forums'); ?></div>
                <div class="frm-unlogged-subtitle"><?php echo sprintf(__('It seems no comment contain term %s, you may try to search with different keyword', 'forums'), '<strong>' . $term . '</strong>'); ?></div>
              <?php } ?>

              <div class="frm-auth-buttons">
                <form action="<?php echo osc_route_url('frm-search-pre'); ?>" method="POST">
                  <input type="hidden" name="frmAction" value="search" />
                  <input type="text" name="searchWord" id="frm-keyword" placeholder="<?php echo osc_esc_html(__('Keyword or phrase', 'forums')); ?>"/>
                  <button class="frm-auth" type="submit"><i class="fa fa-search"></i> <?php _e('Search', 'forums'); ?></button>
                </form>
              </div>
            </div>
            <?php
          }
        ?>
      </div>


      <!-- BOTTOM PAGINATION -->
      <?php if(count($posts) > 0 && $term_filled) { ?>
        <?php echo frm_paginate('', '', '', 'search', $page_id, $per_page, $count, 'frm-pagination-topic'); ?>
      <?php } ?>

    </div>
  </div>
</div>