<?php
  $topic_id = Params::getParam('topicId');
  $page_id = Params::getParam('pageId');
  $page_id = ($page_id > 0 ? $page_id : 1);
  $per_page = frm_param('posts_per_page');

  $limit = array($per_page, $page_id);

  $topic = ModelFRM::newInstance()->getTopic($topic_id);
 
  if(!isset($topic['pk_i_id']) || $topic['pk_i_id'] <= 0) {
    osc_add_flash_error_message(__('This topic does not exists anymore', 'forums'));

    header('Location:' . osc_route_url('frm-home'));
    exit;
  }
  
  $board = ModelFRM::newInstance()->getBoard($topic['fk_i_board_id']);
  $posts = ModelFRM::newInstance()->getPosts($topic_id, $limit);
  $users = ModelFRM::newInstance()->getUsers($topic['s_active_users_ids']);


  // Check if user can see this topic
  if(!frm_control_user(osc_logged_user_id(), $board)) {
    osc_add_flash_error_message(
      __('This board is available only to premium members', 'forums') . '. ' 
      . __('You have to be member of one of following groups to have access there:', 'forums') . ' ' 
      . frm_board_groups($board)
    );

    header('Location:' . osc_route_url('frm-home'));
    exit;
  }


  if(isset($users[$topic['fk_i_user_id']])) {
    $author = $users[$topic['fk_i_user_id']];
  } else {
    $author = ModelFRM::newInstance()->getUser($topic['fk_i_user_id']);
  }

  if(osc_is_web_user_logged_in()) {
    if(isset($users[osc_logged_user_id()])) {
      $logged = $users[osc_logged_user_id()];
    } else {
      $logged = ModelFRM::newInstance()->getUser(osc_logged_user_id());
    }
  } else {
    $logged = false;
  }


  // ACTIONS ON TOPICS
  if(Params::getParam('topicAction') <> '') {
    $action = Params::getParam('topicAction');
    $topic_id = Params::getParam('topicId');

    if($logged && (frm_check_privilege($logged, $board) || @$logged['pk_i_id'] == $topic['fk_i_user_id'])) {

      // LOCK OR UNLOCK
      if($action == 'lock') {
        if($topic['b_locked'] == 0 || ($topic['b_locked'] == 1 && (@$logged['pk_i_id'] == $topic['fk_i_locked_by'] || frm_check_privilege($logged, $board)))) {
          if($topic['b_locked'] == 0) {
            osc_add_flash_ok_message(__('Topic successfully locked', 'forums'));
          } else {
            osc_add_flash_ok_message(__('Topic successfully unlocked', 'forums'));
          }

          ModelFRM::newInstance()->updateTopicSpecial($topic_id, $action);

        } else {
          osc_add_flash_error_message(__('You are not authorized to unlock this topic', 'forums'));

        }
      }


      // MARK AS SOLVED
      if($action == 'solve') {
        ModelFRM::newInstance()->updateTopicSpecial($topic_id, $action);

        if($topic['b_solved'] == 0) {
          osc_add_flash_ok_message(__('Topic successfully marked as solved', 'forums'));
        } else {
          osc_add_flash_ok_message(__('Topic successfully marked as unsolved', 'forums'));
        }
      }


      // STICK OR UNSTICK
      if($action == 'stick') {
        ModelFRM::newInstance()->updateTopicSpecial($topic_id, $action);

        if($topic['b_sticky'] == 0) {
          osc_add_flash_ok_message(__('Topic successfully sticked to top', 'forums'));
        } else {
          osc_add_flash_ok_message(__('Topic successfully unsticked', 'forums'));
        }
      }


      // REMOVE
      if($action == 'remove') {
        ModelFRM::newInstance()->removeTopic($topic_id);
        osc_add_flash_ok_message(__('Topic successfully removed', 'forums'));

        header('Location:' . frm_board_url($board));
        exit;
      }


    } else {
      osc_add_flash_error_message(__('You are not authorized to do this action', 'forums'));
    }

    header('Location:' . frm_topic_url($topic, $page_id));
    exit;
  }



  // ACTIONS ON POST
  if(Params::getParam('postAction') <> '') {
    $action = Params::getParam('postAction');
    $topic_id = Params::getParam('topicId');
    $post_id = Params::getParam('postId');

    if($logged && (frm_check_privilege($logged, $board) || @$logged['pk_i_id'] == $topic['fk_i_user_id'])) {

      // MARK AS BEST ANSWER
      if($action == 'best') {
        if($topic['fk_i_answer_post_id'] <> $post_id) {
          ModelFRM::newInstance()->updatePostSpecial($topic_id, $post_id, $action);
          osc_add_flash_ok_message(__('Post successfully marked as best answer', 'forums'));

        } else {
          ModelFRM::newInstance()->updatePostSpecial($topic_id, 0, $action);
          osc_add_flash_ok_message(__('Post successfully unmarked as best answer', 'forums'));
        }
      }

      // REMOVE
      if($action == 'remove') {
        ModelFRM::newInstance()->removePost($post_id);

        if($topic['fk_i_answer_post_id'] == $post_id) {
          ModelFRM::newInstance()->updatePostSpecial($topic_id, 0, 'best');
        }

        osc_add_flash_ok_message(__('Post successfully removed', 'forums'));

        header('Location:' . frm_topic_url($topic, $page_id));
        exit;
      }

    } else {
      osc_add_flash_error_message(__('You are not authorized to do this action', 'forums'));
    }

    header('Location:' . frm_topic_url($topic, $page_id));
    exit;
  }


  // NEW POST SENT
  if(Params::getParam('frmAction') == 'send') {

    // CHECK IF NOT EMPTY
    if(strip_tags(Params::getParam('message')) == '') {
      osc_add_flash_error_message(__('You must put body when creating new post!', 'forums'));

      header('Location:' . frm_topic_url($topic));
      exit;
    }


    if(Params::getParam('postId') > 0) {
       $post = ModelFRM::newInstance()->getPost(Params::getParam('postId'));

       if($logged && (frm_check_privilege($logged, $board) || @$logged['pk_i_id'] == $post['fk_i_user_id'])) {
         ModelFRM::newInstance()->updatePost($board, $topic, $post, nl2br(Params::getParam('message', false, false)), Params::getFiles('frmAttachment'));
         osc_add_flash_ok_message(__('Message has been successfully updated', 'forums'));

         header('Location:' . frm_post_url($topic, $post));
         exit;

       } else {
         osc_add_flash_ok_message(__('You are not authorized to update this post', 'forums'));
       }

    } else {
      $id = ModelFRM::newInstance()->insertPost($board, $topic, nl2br(Params::getParam('message', false, false)), Params::getFiles('frmAttachment'));
      $post = ModelFRM::newInstance()->getPost($id);

      osc_add_flash_ok_message(__('Your message has been successfully submitted', 'forums'));
    }

    header('Location:' . frm_post_url($topic, $post));
    exit;
  }


  // UPDATE STATS
  ModelFRM::newInstance()->updateTopicStats($topic, 'view', 1);
  ModelFRM::newInstance()->updateBoardRead(osc_logged_user_id(), $board['pk_i_id']);
  ModelFRM::newInstance()->updateTopicRead(osc_logged_user_id(), $board['pk_i_id'], $topic_id);

?>



<div id="frm-body" class="frm-body frm-theme-<?php echo osc_current_web_theme(); ?>">
  <div id="frm-main">
    <div class="frm-content">
      <?php echo frm_breadcrumbs(); ?>

      <div class="frm-title-left">
        <div class="frm-tpc-top">
          <div class="frm-img">
            <img src="<?php echo frm_user_img($author); ?>"/>
          </div>

          <div class="frm-headers">
            <div class="frm-title">
              <?php if($topic['b_sticky'] == 1) { ?>
                <i class="fa fa-thumb-tack frm-sticky frm-has-tooltip" title="<?php echo osc_esc_html(__('Topic is sticked to top', 'forums')); ?>"></i>
              <?php } ?>

              <?php if($topic['b_locked'] == 1) { ?>
                <i class="fa fa-lock frm-locked frm-has-tooltip" title="<?php echo osc_esc_html(__('Topic is locked', 'forums')); ?>"></i>
              <?php } ?>

              <?php if($topic['b_solved'] == 1) { ?>
                <i class="fa fa-lightbulb-o frm-solved frm-has-tooltip" title="<?php echo osc_esc_html(__('Topic has been marked as solved', 'forums')); ?>"></i>
              <?php } ?>
            
              <h1><?php echo $topic['s_title']; ?></h1>
            </div>

            <div class="frm-subtitle">
              <h2><?php echo sprintf(__('Submitted by %s, %s in %s', 'forums'), '<a href="' . frm_user_url($author) . '">' . frm_user_name($author) . '</a>', date('j. M Y', strtotime($topic['dt_created'])), '<a href="' . frm_board_url($board) . '">' . frm_name($board) . '</a>') ?></h2>
            </div>
          </div>
        </div>
      </div>

      <div class="frm-title-right">
        <?php if(osc_is_web_user_logged_in()) { ?>
          <a href="<?php echo osc_route_url('frm-new-topic', array('boardId' => $board['pk_i_id'])); ?>" class="frm-new-topic"><?php _e('Create a new topic', 'forums'); ?></a>
        <?php } ?>
      </div>


      <div class="frm-clear">

        <!-- TOP PAGINATION -->
        <?php echo frm_paginate($board, $topic, '', 'topic', $page_id, $per_page, $topic['i_num_posts'], 'frm-pagination-topic'); ?>

        <?php if($logged && (frm_check_privilege($logged, $board) || @$logged['pk_i_id'] == $topic['fk_i_user_id'])) { ?> 
          <div class="frm-topic-manage">
            <?php if($topic['b_locked'] == 0) { ?>
              <a href="<?php echo frm_topic_manage_url($topic_id, 'lock'); ?>" class="frm-lock frm-has-tooltip" title="<?php echo osc_esc_html(__('Lock topic', 'forums')); ?>"><i class="fa fa-lock"></i> <span><?php _e('Lock', 'forums'); ?></span></a>
            <?php } else if ($topic['b_locked'] == 1 && (@$logged['pk_i_id'] == $topic['fk_i_locked_by'] || frm_check_privilege($logged, $board))) { ?>
              <a href="<?php echo frm_topic_manage_url($topic_id, 'lock'); ?>" class="frm-lock frm-has-tooltip" title="<?php echo osc_esc_html(__('Unlock topic', 'forums')); ?>"><i class="fa fa-unlock-alt"></i> <span><?php _e('Unlock', 'forums'); ?></span></a>
            <?php } ?>

            <?php if(frm_check_privilege($logged, $board)) { ?>
              <a href="<?php echo frm_topic_manage_url($topic_id, 'stick'); ?>" class="frm-stick frm-has-tooltip" title="<?php echo osc_esc_html($topic['b_sticky'] == 0 ? __('Stick topic', 'forums') : __('Unstick topic', 'forums')); ?>"><i class="fa fa-thumb-tack"></i> <span><?php echo ($topic['b_sticky'] == 0 ? __('Stick', 'forums') : __('Unstick', 'forums')); ?></span></a>
            <?php } ?>

            <a href="<?php echo frm_topic_manage_url($topic_id, 'solve'); ?>" class="frm-solve frm-has-tooltip" title="<?php echo osc_esc_html($topic['b_solved'] == 0 ? __('Mark as solved', 'forums') : __('Mark as not solved', 'forums')); ?>"><i class="fa fa-check"></i> <span><?php echo ($topic['b_solved'] == 0 ? __('Solved', 'forums') : __('Not solved', 'forums')); ?></span></a>

            <a href="<?php echo frm_topic_manage_url($topic_id, 'remove'); ?>" class="frm-remove frm-has-tooltip" title="<?php echo osc_esc_html(__('Remove topic', 'forums')); ?>" onclick="return confirm('<?php echo osc_esc_js(__('Are you sure you want to delete this topic? This action cannot be undone', 'forums')); ?>?')"><i class="fa fa-trash-o"></i> <span><?php _e('Remove topic', 'forums'); ?></span></a>
          </div>
        <?php } ?>
      </div>

      <?php if($topic['b_solved'] == 1) { ?>
        <?php 
          if(isset($users[$topic['fk_i_solved_by']])) {
            $solved_user = $users[$topic['fk_i_solved_by']];
          } else {
            $solved_user = ModelFRM::newInstance()->getUser($topic['fk_i_solved_by']);
          }
        ?>

        <div class="frm-solved">
          <div class="frm-left">
            <div class="frm-img"><img src="<?php echo frm_user_img($solved_user); ?>"/></div>
          </div>

          <div class="frm-solved-text">
            <div class="frm-text"><i class="fa fa-check-circle"></i> <?php echo sprintf(__('This topic has been marked as solved by %s on %s', 'forums'), '<a href="' . frm_user_url($solved_user) . '">' . frm_user_name($solved_user) . '</a>', date('j. M Y', strtotime($topic['dt_solved_date']))); ?></div>
          </div>
        </div>
      <?php } ?>



      <div class="frm-posts">
        <?php 
          $counter = 1;

          foreach($posts as $post) {
            if(isset($users[$post['fk_i_user_id']])) {
              $user = $users[$post['fk_i_user_id']];
            } else {
              $user = ModelFRM::newInstance()->getUser($post['fk_i_user_id']);
            }

            frm_generate_post($board, $topic, $post, $counter, '', $user, $logged);

            if($topic['fk_i_answer_post_id'] > 0 && $counter == 1 && $page_id == 1) {
              $answer_post = ModelFRM::newInstance()->getPost($topic['fk_i_answer_post_id']); 
              $answer_user = ModelFRM::newInstance()->getUser($answer_post['fk_i_user_id']);

              frm_generate_post($board, $topic, $answer_post, $counter, 'best', $answer_user, $logged);
            }

            $counter++;
          }
        ?>
      </div>


      <!-- BOTTOM PAGINATION -->
      <div class="frm-clear frm-clear-bottom">
        <?php echo frm_paginate($board, $topic, '', 'topic', $page_id, $per_page, $topic['i_num_posts'], 'frm-pagination-topic'); ?>
        <?php if($logged && (frm_check_privilege($logged, $board) || @$logged['pk_i_id'] == $topic['fk_i_user_id'])) { ?> 
          <div class="frm-topic-manage">
            <?php if($topic['b_locked'] == 0) { ?>
              <a href="<?php echo frm_topic_manage_url($topic_id, 'lock'); ?>" class="frm-lock frm-has-tooltip" title="<?php echo osc_esc_html(__('Lock topic', 'forums')); ?>"><i class="fa fa-lock"></i> <span><?php _e('Lock', 'forums'); ?></span></a>
            <?php } else if ($topic['b_locked'] == 1 && (@$logged['pk_i_id'] == $topic['fk_i_locked_by'] || frm_check_privilege($logged, $board))) { ?>
              <a href="<?php echo frm_topic_manage_url($topic_id, 'lock'); ?>" class="frm-lock frm-has-tooltip" title="<?php echo osc_esc_html(__('Unlock topic', 'forums')); ?>"><i class="fa fa-unlock-alt"></i> <span><?php _e('Unlock', 'forums'); ?></span></a>
            <?php } ?>

            <?php if(frm_check_privilege($logged, $board)) { ?>
              <a href="<?php echo frm_topic_manage_url($topic_id, 'stick'); ?>" class="frm-stick frm-has-tooltip" title="<?php echo osc_esc_html($topic['b_sticky'] == 0 ? __('Stick topic', 'forums') : __('Unstick topic', 'forums')); ?>"><i class="fa fa-thumb-tack"></i> <span><?php echo ($topic['b_sticky'] == 0 ? __('Stick', 'forums') : __('Unstick', 'forums')); ?></span></a>
            <?php } ?>

            <a href="<?php echo frm_topic_manage_url($topic_id, 'solve'); ?>" class="frm-solve frm-has-tooltip" title="<?php echo osc_esc_html($topic['b_solved'] == 0 ? __('Mark as solved', 'forums') : __('Mark as not solved', 'forums')); ?>"><i class="fa fa-check"></i> <span><?php echo ($topic['b_solved'] == 0 ? __('Solved', 'forums') : __('Not solved', 'forums')); ?></span></a>

            <a href="<?php echo frm_topic_manage_url($topic_id, 'remove'); ?>" class="frm-remove frm-has-tooltip" title="<?php echo osc_esc_html(__('Remove topic', 'forums')); ?>" onclick="return confirm('<?php echo osc_esc_js(__('Are you sure you want to delete this topic? This action cannot be undone', 'forums')); ?>?')"><i class="fa fa-trash-o"></i> <span><?php _e('Remove topic', 'forums'); ?></span></a>
          </div>
        <?php } ?>
      </div>



      <div class="frm-answer<?php if(!osc_is_web_user_logged_in()) { ?> frm-unlogged<?php } ?><?php if($topic['b_locked'] == 1) { ?> frm-locked<?php } ?>">
        <?php if($topic['b_locked'] == 1) { ?>
          <?php
            if(isset($users[$topic['fk_i_locked_by']])) {
              $locked_user = $users[$topic['fk_i_locked_by']];
            } else {
              $locked_user = ModelFRM::newInstance()->getUser($topic['fk_i_locked_by']);
            }
          ?>

          <div class="frm-logged-title"><?php _e('Topic is locked', 'forums'); ?></div>

          <div class="frm-left">
            <div class="frm-img"><img src="<?php echo frm_user_img($locked_user); ?>"/></div>
            <strong><?php echo frm_user_name($locked_user); ?></strong>
          </div>

          <div class="frm-area">
            <div class="frm-text"><i class="fa fa-lock"></i> <?php echo sprintf(__('This topic has been locked by %s on %s', 'forums'), '<a href="' . frm_user_url($locked_user) . '">' . frm_user_name($locked_user) . '</a>', date('j. M Y', strtotime($topic['dt_locked_date']))); ?></div>
          </div>


        <?php } else if(!osc_is_web_user_logged_in()) { ?>

          <div class="frm-unlogged-title"><?php _e('Please login or register to comment in this post', 'forums'); ?></div>
          <div class="frm-unlogged-subtitle"><?php _e('Only logged in users can reply to posts. This help to keep forums clean from spam.', 'forums'); ?></div>

          <div class="frm-auth-buttons">
            <a class="frm-auth" href="<?php echo osc_user_login_url(); ?>"><?php _e('Login', 'forums'); ?></a>
            <a class="frm-auth" href="<?php echo osc_register_account_url(); ?>"><?php _e('Register', 'forums'); ?></a>
          </div>

        <?php } else { ?>

          <div class="frm-logged-title"><?php _e('Comment this topic', 'forums'); ?></div>

          <div class="frm-left">
            <div class="frm-img"><img src="<?php echo frm_user_img($logged); ?>"/></div>
            <strong><?php echo frm_user_name($logged); ?></strong>
          </div>


          <div class="frm-area">
            <form action="<?php echo frm_topic_url($topic); ?>" method="POST" enctype="multipart/form-data">
              <input type="hidden" name="frmAction" value="send" />
              <input type="hidden" name="boardId" value="<?php echo $board['pk_i_id']; ?>" />
              <input type="hidden" name="topicId" value="<?php echo $topic['pk_i_id']; ?>" />
              <input type="hidden" name="postId" value="" />

              <div class="frm-text">
                <textarea id="frm-rich" name="message"></textarea>
              </div>

              <div class="frm-buttons">
                <div class="frm-attachments">
                  <div class="frm-attachment frm-has-tooltip" title="<?php echo osc_esc_js(sprintf(__('Maximum file size is %skb. Allowed extensions: %s', 'forums'), 2000, '.pdf, .gif, .jpg')); ?>">
                    <div class="frm-att-box">
                      <label class="frm-status">
                        <span class="frm-wrap"><i class="fa fa-paperclip"></i> <span><?php _e('Attachment', 'forums'); ?></span></span>
                        <input type="file" name="frmAttachment" id="frmAttachment" class="frm-attachment" />
                      </label>
                    </div>
                  </div>
                </div>

                <button type="submit">
                  <span class="frm-pst"><?php _e('Submit comment', 'forums'); ?></span>
                  <span class="frm-edt" style="display:none;"><?php _e('Update comment', 'forums'); ?></span>
                </button>

                <a class="frm-edt-cancel" href="#" style="display:none;"><?php _e('Cancel', 'forums'); ?></a>
              </div>
            </form>
          </div>
        <?php } ?>
      </div>

    </div>
  </div>
</div>

<script>
$(document).ready(function() {

  // GENERATE RICH TEXT
  if($('#frm-rich').length) {
    $('#frm-rich').richText({
      bold: true,
      italic: true,
      underline: true,
      leftAlign: false,
      centerAlign: false,
      rightAlign: false,
      justify: false,
      ol: true,
      ul: true,
      fonts: false,
      fontColor: true,
      fontSize: true,
      heading: false,
      urls: true,
      table: true,
      removeStyles: false,
      code: false,
      colors: [],
      fileHTML: '',
      imageHTML: '',
      translations: {
        'title': '<?php echo osc_esc_js(__('Title', 'forums')); ?>',
        'white': '<?php echo osc_esc_js(__('White', 'forums')); ?>',
        'black': '<?php echo osc_esc_js(__('Black', 'forums')); ?>',
        'brown': '<?php echo osc_esc_js(__('Brown', 'forums')); ?>',
        'beige': '<?php echo osc_esc_js(__('Beige', 'forums')); ?>',
        'darkBlue': '<?php echo osc_esc_js(__('Dark Blue', 'forums')); ?>',
        'blue': '<?php echo osc_esc_js(__('Blue', 'forums')); ?>',
        'lightBlue': '<?php echo osc_esc_js(__('Light Blue', 'forums')); ?>',
        'darkRed': '<?php echo osc_esc_js(__('Dark Red', 'forums')); ?>',
        'red': '<?php echo osc_esc_js(__('Red', 'forums')); ?>',
        'darkGreen': '<?php echo osc_esc_js(__('Dark Green', 'forums')); ?>',
        'green': '<?php echo osc_esc_js(__('Green', 'forums')); ?>',
        'purple': '<?php echo osc_esc_js(__('Purple', 'forums')); ?>',
        'darkTurquois': '<?php echo osc_esc_js(__('Dark Turquois', 'forums')); ?>',
        'turquois': '<?php echo osc_esc_js(__('Turquois', 'forums')); ?>',
        'darkOrange': '<?php echo osc_esc_js(__('Dark Orange', 'forums')); ?>',
        'orange': '<?php echo osc_esc_js(__('Orange', 'forums')); ?>',
        'yellow': '<?php echo osc_esc_js(__('Yellow', 'forums')); ?>',
        'imageURL': '<?php echo osc_esc_js(__('Image URL', 'forums')); ?>',
        'fileURL': '<?php echo osc_esc_js(__('File URL', 'forums')); ?>',
        'linkText': '<?php echo osc_esc_js(__('Link text', 'forums')); ?>',
        'url': '<?php echo osc_esc_js(__('URL', 'forums')); ?>',
        'size': '<?php echo osc_esc_js(__('Responsive', 'forums')); ?>Size',
        'responsive': '<?php echo osc_esc_js(__('Title', 'forums')); ?>',
        'text': '<?php echo osc_esc_js(__('Text', 'forums')); ?>',
        'openIn': '<?php echo osc_esc_js(__('Open in', 'forums')); ?>',
        'sameTab': '<?php echo osc_esc_js(__('Same tab', 'forums')); ?>',
        'newTab': '<?php echo osc_esc_js(__('New tab', 'forums')); ?>',
        'align': '<?php echo osc_esc_js(__('Align', 'forums')); ?>',
        'left': '<?php echo osc_esc_js(__('Left', 'forums')); ?>',
        'center': '<?php echo osc_esc_js(__('Center', 'forums')); ?>',
        'right': '<?php echo osc_esc_js(__('Right', 'forums')); ?>',
        'rows': '<?php echo osc_esc_js(__('Rows', 'forums')); ?>',
        'columns': '<?php echo osc_esc_js(__('Columns', 'forums')); ?>',
        'add': '<?php echo osc_esc_js(__('Add', 'forums')); ?>',
        'pleaseEnterURL': '<?php echo osc_esc_js(__('Please enter an URL', 'forums')); ?>',
        'videoURLnotSupported': '<?php echo osc_esc_js(__('Video URL not supported', 'forums')); ?>',
        'pleaseSelectImage': '<?php echo osc_esc_js(__('Please select an image', 'forums')); ?>',
        'pleaseSelectFile': '<?php echo osc_esc_js(__('Please select a file', 'forums')); ?>',
        'bold': '<?php echo osc_esc_js(__('Bold', 'forums')); ?>',
        'italic': '<?php echo osc_esc_js(__('Italic', 'forums')); ?>',
        'underline': '<?php echo osc_esc_js(__('Underline', 'forums')); ?>',
        'addOrderedList': '<?php echo osc_esc_js(__('Add ordered list', 'forums')); ?>',
        'addUnorderedList': '<?php echo osc_esc_js(__('Add unordered list', 'forums')); ?>',
        'addHeading': '<?php echo osc_esc_js(__('Add Heading/title', 'forums')); ?>',
        'addFont': '<?php echo osc_esc_js(__('Add font', 'forums')); ?>',
        'addFontColor': '<?php echo osc_esc_js(__('Add font color', 'forums')); ?>',
        'addFontSize' : '<?php echo osc_esc_js(__('Add font size', 'forums')); ?>',
        'addImage': '<?php echo osc_esc_js(__('Add image', 'forums')); ?>',
        'addVideo': '<?php echo osc_esc_js(__('Add video', 'forums')); ?>',
        'addFile': '<?php echo osc_esc_js(__('Add file', 'forums')); ?>',
        'addURL': '<?php echo osc_esc_js(__('Add URL', 'forums')); ?>',
        'addTable': '<?php echo osc_esc_js(__('Add table', 'forums')); ?>',
        'removeStyles': '<?php echo osc_esc_js(__('Remove styles', 'forums')); ?>',
        'code': '<?php echo osc_esc_js(__('Show HTML code', 'forums')); ?>',
        'undo': '<?php echo osc_esc_js(__('Undo', 'forums')); ?>',
        'redo': '<?php echo osc_esc_js(__('Redo', 'forums')); ?>',
        'close': '<?php echo osc_esc_js(__('Close', 'forums')); ?>'
      },

      useSingleQuotes: false,
      height: 200,
      heightPercentage: 0,
      id: "frm-richeditor",
      class: "frm-richeditor",
      useParagraph: false
    });

    Tipped.create('.richText-btn', { maxWidth: 200, radius: false, behavior: 'hide'});
  }
});
</script>