<?php
  $board_id = Params::getParam('boardId');
  $board = ModelFRM::newInstance()->getBoard($board_id);

  if(osc_is_web_user_logged_in()) {
    $logged = ModelFRM::newInstance()->getUser(osc_logged_user_id());
  } else {
    $logged = false;
  }



  // NEW TOPIC CREATED
  if(Params::getParam('frmAction') == 'create') {
  
    // CHECK IF NOT EMPTY
    if(strip_tags(Params::getParam('title')) == '' || strip_tags(Params::getParam('message')) == '') {
      osc_add_flash_error_message(__('You must put title and body when creating new topic!', 'forums'));

      header('Location:' . osc_route_url('frm-new-topic', array('boardId' => $board_id)));
      exit;
    }


    $topic_id = ModelFRM::newInstance()->insertTopic($board, strip_tags(Params::getParam('title')));
    $topic = ModelFRM::newInstance()->getTopic($topic_id);


    $post_id = ModelFRM::newInstance()->insertPost($board, $topic, nl2br(Params::getParam('message', false, false)), Params::getFiles('frmAttachment'));
    ModelFRM::newInstance()->updateFirstPostId($topic_id, $post_id);

    osc_add_flash_ok_message(__('Topic has been successfully created', 'forums'));

    header('Location:' . frm_topic_url($topic));
    exit;
  }

?>


<div id="frm-body" class="frm-body frm-theme-<?php echo osc_current_web_theme(); ?>">
  <div id="frm-main">
    <div class="frm-content">
      <?php echo frm_breadcrumbs(); ?>


      <div class="frm-answer<?php if(!osc_is_web_user_logged_in()) { ?> frm-unlogged<?php } ?>">
        <?php if(!osc_is_web_user_logged_in()) { ?>

          <div class="frm-unlogged-title"><?php _e('Please login or register to comment in this post', 'forums'); ?></div>
          <div class="frm-unlogged-subtitle"><?php _e('Only logged in users can reply to posts. This help to keep forums clean from spam.', 'forums'); ?></div>

          <div class="frm-auth-buttons">
            <a class="frm-auth" href="<?php echo osc_user_login_url(); ?>"><?php _e('Login', 'forums'); ?></a>
            <a class="frm-auth" href="<?php echo osc_register_account_url(); ?>"><?php _e('Register', 'forums'); ?></a>
          </div>

        <?php } else { ?>

          <div class="frm-logged-title"><?php _e('Create a new topic', 'forums'); ?></div>
          <div class="frm-logged-subtitle"><?php _e('In board', 'forums'); ?> <a href="<?php echo frm_board_url($board); ?>"><?php echo frm_name($board); ?></a></div>

          <div class="frm-left frm-left-new">
            <div class="frm-img"><img src="<?php echo frm_user_img($logged); ?>"/></div>
            <strong><?php echo frm_user_name($logged); ?></strong>
          </div>


          <div class="frm-area">
            <form action="<?php echo osc_route_url('frm-new-topic', array('boardId' => $board_id)); ?>" method="POST" enctype="multipart/form-data">
              <input type="hidden" name="frmAction" value="create" />

              <div class="frm-toptext">
                <input type="text" name="title" id="frm-title" value="" placeholder="<?php echo osc_esc_html(__('Topic title', 'forums')); ?>" required />
              </div>

              <div class="frm-text">
                <textarea id="frm-rich" name="message"></textarea>
              </div>

              <div class="frm-buttons">
                <div class="frm-attachments">
                  <div class="frm-attachment frm-has-tooltip" title="<?php echo osc_esc_js(sprintf(__('Maximum file size is %skb. Allowed extensions: %s', 'forums'), 2000, '.pdf, .gif, .jpg')); ?>">
                    <div class="frm-att-box">
                      <label class="frm-status">
                        <span class="frm-wrap"><i class="fa fa-paperclip"></i> <span><?php _e('Attachment', 'forums'); ?></span></span>
                        <input type="file" name="frmAttachment" id="frmAttachment" class="frm-attachment" />
                      </label>
                    </div>
                  </div>
                </div>

                <button type="submit">
                  <span class="frm-pst"><?php _e('Submit topic', 'forums'); ?></span>
                </button>
              </div>
            </form>
          </div>
        <?php } ?>
      </div>

    </div>
  </div>
</div>


<script>
$(document).ready(function() {

  // GENERATE RICH TEXT
  if($('#frm-rich').length) {
    $('#frm-rich').richText({
      bold: true,
      italic: true,
      underline: true,
      leftAlign: false,
      centerAlign: false,
      rightAlign: false,
      justify: false,
      ol: true,
      ul: true,
      fonts: false,
      fontColor: true,
      fontSize: true,
      heading: false,
      urls: true,
      table: true,
      removeStyles: false,
      code: false,
      colors: [],
      fileHTML: '',
      imageHTML: '',
      translations: {
        'title': '<?php echo osc_esc_js(__('Title', 'forums')); ?>',
        'white': '<?php echo osc_esc_js(__('White', 'forums')); ?>',
        'black': '<?php echo osc_esc_js(__('Black', 'forums')); ?>',
        'brown': '<?php echo osc_esc_js(__('Brown', 'forums')); ?>',
        'beige': '<?php echo osc_esc_js(__('Beige', 'forums')); ?>',
        'darkBlue': '<?php echo osc_esc_js(__('Dark Blue', 'forums')); ?>',
        'blue': '<?php echo osc_esc_js(__('Blue', 'forums')); ?>',
        'lightBlue': '<?php echo osc_esc_js(__('Light Blue', 'forums')); ?>',
        'darkRed': '<?php echo osc_esc_js(__('Dark Red', 'forums')); ?>',
        'red': '<?php echo osc_esc_js(__('Red', 'forums')); ?>',
        'darkGreen': '<?php echo osc_esc_js(__('Dark Green', 'forums')); ?>',
        'green': '<?php echo osc_esc_js(__('Green', 'forums')); ?>',
        'purple': '<?php echo osc_esc_js(__('Purple', 'forums')); ?>',
        'darkTurquois': '<?php echo osc_esc_js(__('Dark Turquois', 'forums')); ?>',
        'turquois': '<?php echo osc_esc_js(__('Turquois', 'forums')); ?>',
        'darkOrange': '<?php echo osc_esc_js(__('Dark Orange', 'forums')); ?>',
        'orange': '<?php echo osc_esc_js(__('Orange', 'forums')); ?>',
        'yellow': '<?php echo osc_esc_js(__('Yellow', 'forums')); ?>',
        'imageURL': '<?php echo osc_esc_js(__('Image URL', 'forums')); ?>',
        'fileURL': '<?php echo osc_esc_js(__('File URL', 'forums')); ?>',
        'linkText': '<?php echo osc_esc_js(__('Link text', 'forums')); ?>',
        'url': '<?php echo osc_esc_js(__('URL', 'forums')); ?>',
        'size': '<?php echo osc_esc_js(__('Responsive', 'forums')); ?>Size',
        'responsive': '<?php echo osc_esc_js(__('Title', 'forums')); ?>',
        'text': '<?php echo osc_esc_js(__('Text', 'forums')); ?>',
        'openIn': '<?php echo osc_esc_js(__('Open in', 'forums')); ?>',
        'sameTab': '<?php echo osc_esc_js(__('Same tab', 'forums')); ?>',
        'newTab': '<?php echo osc_esc_js(__('New tab', 'forums')); ?>',
        'align': '<?php echo osc_esc_js(__('Align', 'forums')); ?>',
        'left': '<?php echo osc_esc_js(__('Left', 'forums')); ?>',
        'center': '<?php echo osc_esc_js(__('Center', 'forums')); ?>',
        'right': '<?php echo osc_esc_js(__('Right', 'forums')); ?>',
        'rows': '<?php echo osc_esc_js(__('Rows', 'forums')); ?>',
        'columns': '<?php echo osc_esc_js(__('Columns', 'forums')); ?>',
        'add': '<?php echo osc_esc_js(__('Add', 'forums')); ?>',
        'pleaseEnterURL': '<?php echo osc_esc_js(__('Please enter an URL', 'forums')); ?>',
        'videoURLnotSupported': '<?php echo osc_esc_js(__('Video URL not supported', 'forums')); ?>',
        'pleaseSelectImage': '<?php echo osc_esc_js(__('Please select an image', 'forums')); ?>',
        'pleaseSelectFile': '<?php echo osc_esc_js(__('Please select a file', 'forums')); ?>',
        'bold': '<?php echo osc_esc_js(__('Bold', 'forums')); ?>',
        'italic': '<?php echo osc_esc_js(__('Italic', 'forums')); ?>',
        'underline': '<?php echo osc_esc_js(__('Underline', 'forums')); ?>',
        'addOrderedList': '<?php echo osc_esc_js(__('Add ordered list', 'forums')); ?>',
        'addUnorderedList': '<?php echo osc_esc_js(__('Add unordered list', 'forums')); ?>',
        'addHeading': '<?php echo osc_esc_js(__('Add Heading/title', 'forums')); ?>',
        'addFont': '<?php echo osc_esc_js(__('Add font', 'forums')); ?>',
        'addFontColor': '<?php echo osc_esc_js(__('Add font color', 'forums')); ?>',
        'addFontSize' : '<?php echo osc_esc_js(__('Add font size', 'forums')); ?>',
        'addImage': '<?php echo osc_esc_js(__('Add image', 'forums')); ?>',
        'addVideo': '<?php echo osc_esc_js(__('Add video', 'forums')); ?>',
        'addFile': '<?php echo osc_esc_js(__('Add file', 'forums')); ?>',
        'addURL': '<?php echo osc_esc_js(__('Add URL', 'forums')); ?>',
        'addTable': '<?php echo osc_esc_js(__('Add table', 'forums')); ?>',
        'removeStyles': '<?php echo osc_esc_js(__('Remove styles', 'forums')); ?>',
        'code': '<?php echo osc_esc_js(__('Show HTML code', 'forums')); ?>',
        'undo': '<?php echo osc_esc_js(__('Undo', 'forums')); ?>',
        'redo': '<?php echo osc_esc_js(__('Redo', 'forums')); ?>',
        'close': '<?php echo osc_esc_js(__('Close', 'forums')); ?>'
      },

      useSingleQuotes: false,
      height: 200,
      heightPercentage: 0,
      id: "frm-richeditor",
      class: "frm-richeditor",
      useParagraph: false
    });

    Tipped.create('.richText-btn', { maxWidth: 200, radius: false, behavior: 'hide'});
  }
});
</script>