<?php

// DELETE USER RECORD IF USER IS REMOVED FROM OSCLASS
function frm_user_removed($user_id) {
  if($user_id > 0) {
    ModelFRM::newInstance()->removeUser($user_id);
  }  
}

osc_add_hook('delete_user', 'frm_user_removed');


// UPDATE USER PROFILE WHEN USER IS CREATED
function frm_osclass_user_created($user_id) {
  $user = User::newInstance()->findByPrimaryKey($user_id);
  ModelFRM::newInstance()->insertUser($user_id, $user['s_name']);
}

osc_add_hook('user_register_completed', 'frm_osclass_user_created');


// ADD LINK TO HEADER
function frm_header_link_hook() {
  if(frm_param('hook_header_links') == 1) {
    echo '<a href="' . frm_home() . '">' . __('Forums', 'forums') . '</a>';    
  }
}

osc_add_hook('header_links', 'frm_header_link_hook');

 
// GET LAST CREATED TOPICS
function frm_last_created_topics($limit = 5) {
  $topics = ModelFRM::newInstance()->getLastCreatedTopics($limit);
  
  if(is_array($topics) && count($topics) > 0) {
  ?>
  <div class="frm-widget frm-tpc">
    <div class="frm-header"><?php _e('Most recent topics', 'forums'); ?></div>
    
    <?php foreach($topics as $topic) { ?>
      <?php
        $submitter = ModelFRM::newInstance()->getUser($topic['fk_i_user_id']);
      ?>
      <div class="frm-row">
        <div class="frm-top"><a href="<?php echo frm_topic_url($topic); ?>"><?php echo osc_highlight($topic['s_title'], 60); ?></a></div>
        <div class="frm-bot">
          <span><?php _e('By', 'forums'); ?></span>
          <a href="<?php echo frm_user_url($submitter); ?>"><?php echo frm_user_name($submitter); ?></a>
          <span><?php _e('on', 'forums'); ?></span>
          <span><?php echo date('j. M Y', strtotime($topic['dt_created'])); ?></span>
        </div>
      </div>
    <?php } ?>
  </div>
  <?php
  }
}

// GET LAST TOPICS
function frm_last_active_topics($limit = 5) {
  $topics = ModelFRM::newInstance()->getLastActiveTopics($limit);
  
  if(is_array($topics) && count($topics) > 0) {
  ?>
  <div class="frm-widget frm-tpc">
    <div class="frm-header"><?php _e('Last active topics', 'forums'); ?></div>
    
    <?php foreach($topics as $topic) { ?>
      <?php
        $last_user = ModelFRM::newInstance()->getUser($topic['fk_i_last_user_id']);
      ?>
      <div class="frm-row">
        <div class="frm-top"><a href="<?php echo frm_topic_url($topic); ?>"><?php echo osc_highlight($topic['s_title'], 60); ?></a></div>
        <div class="frm-bot">
          <span><?php _e('By', 'forums'); ?></span>
          <a href="<?php echo frm_user_url($last_user); ?>"><?php echo frm_user_name($last_user); ?></a>
          <span><?php _e('on', 'forums'); ?></span>
          <span><?php echo date('j. M Y', strtotime($topic['dt_last_activity'])); ?></span>
        </div>
      </div>
    <?php } ?>
  </div>
  <?php
  }
}


// CUSTOM COLORS
function frm_custom_colors() {
  $html = '<style>';
  
  if(frm_param('links_color') != '' && frm_param('links_color') != '#33659C') {
    $html .= 'body .frm-body a, body .frm-body a:hover {color:' . frm_param('links_color') . ';}';
  }
  
  if(frm_param('category_color') != '' && frm_param('category_color') != '#437dbf') {
    $html .= 'body .frm-category {background:' . frm_param('category_color') . ';}';
  }
  
  if(frm_param('button1_color') != '' && frm_param('button1_color') != '#9cc845') {
    $html .= 'body .frm-title-right a.frm-new-topic, body .frm-title-right a.frm-new-topic:hover {background:' . frm_param('button1_color') . ';}';
  }
  
  if(frm_param('button2_color') != '' && frm_param('button2_color') != '#333333') {
    $html .= 'body .frm-answer .frm-area .frm-buttons button, body .frm-answer .frm-area .frm-buttons button:hover, body .frm-profile .frm-user-data button.frm-update-profile, body .frm-profile .frm-user-data button.frm-update-profile:hover, body .frm-answer .frm-auth, body .frm-answer .frm-auth:hover {background:' . frm_param('button2_color') . ';}';
  }
  
  $html .= '</style>';
  echo $html;
}

osc_add_hook('header', 'frm_custom_colors', 10);


// META TITLE
function frm_meta_title($tag) {
  $location = Rewrite::newInstance()->get_location();
  $section  = Rewrite::newInstance()->get_section();

  if($location == 'frm') {
    if($section == 'home-section') {
      $tag = __('Forums', 'forums') . ' - ' . osc_page_title();

    } else if ($section == 'topic-new-section') {
      $tag = __('Create a new topic', 'forums') . ' - ' . osc_page_title();
      
    } else if ($section == 'board-section') {
      $board = ModelFRM::newInstance()->getBoard(Params::getParam('boardId'));
      $name = (frm_name($board) <> '' ? frm_name($board) : __('Board', 'forums'));
      
      $tag = $name . ' - ' . osc_page_title();
    
    } else if ($section == 'topic-section') {
      $topic = ModelFRM::newInstance()->getTopic(Params::getParam('topicId'));
      $name = (@$topic['s_title'] <> '' ? $topic['s_title'] : __('Topic', 'forums'));
      
      if(isset($topic['fk_i_board_id']) && $topic['fk_i_board_id'] > 0) {
        $board = ModelFRM::newInstance()->getBoard($topic['fk_i_board_id']);

        if(frm_name($board) <> '') {
          $name .= ' - ' . frm_name($board);
        }
      }
      
      $tag = $name . ' - ' . osc_page_title();
      
    } else if ($section == 'search-section') {
      $tag = sprintf(__('Search results for %s', 'forums'), urldecode(Params::getParam('searchTerm'))) . ' - ' . osc_page_title();

    } else if ($section == 'activity-section') {
      $tag = __('Latest activity on forums', 'forums') . ' - ' . osc_page_title();

    } else if ($section == 'profile-section') {
      $user = ModelFRM::newInstance()->getUser(Params::getParam('userId'));

      if(isset($user['fk_i_user_id'])) {
        $tag = sprintf(__('%s\'s forums profile', 'forums'), frm_user_name($user)) . ' - ' . osc_page_title();
      } else {
        $tag = __('Forums profile', 'forums') . ' - ' . osc_page_title();
      }

    } else if ($section == 'user-section') {
      $user = ModelFRM::newInstance()->getUser(Params::getParam('userId'));

      if(isset($user['fk_i_user_id'])) {
        $tag = sprintf(__('%s\'s posts', 'forums'), frm_user_name($user)) . ' - ' . osc_page_title();
      } else {
        $tag = __('User posts', 'forums') . ' - ' . osc_page_title();
      }
      
    }
  }

  return $tag;
}

osc_add_filter('meta_title_filter', 'frm_meta_title', 6);
osc_add_filter('structured_data_title_filter', 'frm_meta_title', 6);


// META DESCRIPTION
function frm_meta_description($tag) {
  $location = Rewrite::newInstance()->get_location();
  $section  = Rewrite::newInstance()->get_section();

  if($location == 'frm') {
    if($section == 'home-section') {
      $tag = __('Welcome to our forums, you may find a lot of helpful topics there.', 'forums');

    } else if ($section == 'topic-new-section') {
      $tag = __('Create a new topic in case similar does not exists yet. Other users may reply to your question or suggest you solutions.', 'forums');
      
    } else if ($section == 'board-section') {
      $board = ModelFRM::newInstance()->getBoard(Params::getParam('boardId'));
      $name = (frm_description($board) <> '' ? frm_description($board) : __('Board contains similar topics on particular issue or question.', 'forums'));
      
      $tag = $name;
    
    } else if ($section == 'topic-section') {
      $topic = ModelFRM::newInstance()->getTopic(Params::getParam('topicId'));
      $post = ModelFRM::newInstance()->getPost(@$topic['fk_i_first_post_id']);
      $desc = trim(strip_tags(@$post['s_body']));

      $name = ($desc <> '' ? $desc : __('Reply to this topic if you have similar issue, question or you have solution.', 'forums'));
      
      $tag = $name;
      
    } else if ($section == 'search-section') {
      $tag = __('All posts that match to searched keyword or term.', 'forums');

    } else if ($section == 'profile-section') {
      $tag = __('User profile that is used exclusively on forums only. You may setup forum user name, motto, role, avatar and much more.', 'forums');

    } else if ($section == 'user-section') {
      $tag = __('All comments and posts from this user. Posts are sorted from most recent entry.', 'forums');

    }
  }

  return $tag;
}

osc_add_filter('meta_description_filter', 'frm_meta_description', 6);
osc_add_filter('structured_data_description_filter', 'frm_meta_description', 6);


// RECALCULATE ALL STATS
function frm_recalculate_stats() {

  // Topic stats
  $topics = ModelFRM::newInstance()->getStatTopics();

  if(count($topics) > 0) {
    foreach($topics as $topic) {
      $data = array();
      $data['i_num_posts'] = ModelFRM::newInstance()->countTopicPosts($topic['pk_i_id']);

      ModelFRM::newInstance()->updateTopicStatsGlobal($topic['pk_i_id'], $data);
    }
  }


  // Board stats
  $boards = ModelFRM::newInstance()->getStatBoards();

  if(count($boards) > 0) {
    foreach($boards as $board) {
      $data = array();

      $ids = ModelFRM::newInstance()->getBoardChildren($board['pk_i_id']);
      $ids[] = $board['pk_i_id'];
      $ids = implode(',', $ids);

      $data['i_num_posts'] = ModelFRM::newInstance()->countBoardPosts($ids);
      $data['i_num_topics'] = ModelFRM::newInstance()->countBoardTopics($ids);

      ModelFRM::newInstance()->updateBoardStatsGlobal($board['pk_i_id'], $data);
    }
  }


  // User stats
  $users = ModelFRM::newInstance()->getStatUsers();

  if(count($users) > 0) {
    foreach($users as $user) {
      $data = array();
      $data['i_num_posts'] = ModelFRM::newInstance()->countUserPosts($user['fk_i_user_id']);
      $data['i_num_topics'] = ModelFRM::newInstance()->countUserTopics($user['fk_i_user_id']);

      ModelFRM::newInstance()->updateUserStatsGlobal($user['fk_i_user_id'], $data);
    }
  }


}

osc_add_hook('cron_daily', 'frm_recalculate_stats');



// GET USER DATA - AJAX
function frm_superuser() {
  $user_id = Params::getParam('id');
  
  if($user_id <> '' && $user_id > 0) {
    $user = ModelFRM::newInstance()->getUser($user_id);
    echo json_encode(array('user' => array('id' => $user_id, 'name' => $user['s_name'], 'email' => $user['s_email'], 'moderator' => $user['b_moderator'], 'admin' => $user['b_admin'])));
  } else {
    echo json_encode(array('user' => array('id' => 0, 'name' => '', 'email' =>'', 'moderator' => '', 'admin' => '')));
  }

  exit;
}

osc_add_hook('ajax_admin_frm_superuser', 'frm_superuser');




// PREPARE BOARD FOR SORT
function frm_board_list_ol($boards) {
 if(count($boards) > 0 && is_array($boards)) {
    foreach($boards as $b) {
      ?>

      <li class="mb-board" id="board_<?php echo $b['pk_i_id']; ?>">
        <div>
          <i class="fa fa-arrows move"></i>
          <span><?php echo (frm_name($b) <> '' ? frm_name($b) : __('New board', 'forums')); ?></span>
        </div>

        <ol>
          <?php 
            //$subboards = ModelFRM::newInstance()->getBoards($b['fk_i_category_id'], $b['pk_i_id']);
            if(isset($b['children']) && count($b['children']) > 0) { 
              frm_board_list_ol($b['children']); 
            }
          ?>
        </ol>
      </li>
    <?php
    }
  }
}


// UPDATE CATEGORY POSITION - AJAX
function frm_category_position() {
  $order = json_decode(Params::getParam('list'), true);

  if(is_array($order) && count($order) > 0) {
    $i = 0;
    foreach($order as $o) {
      ModelFRM::newInstance()->updateCategoryPosition($o['c'], $i+1);
      $i++;
    }
  }

  exit;
}

osc_add_hook('ajax_admin_frm_category_position', 'frm_category_position');


// UPDATE BOARD POSITION - AJAX
function frm_board_position() {
  $order = json_decode(Params::getParam('list'), true);

  if(is_array($order) && count($order) > 0) {
    $i = 0;
    foreach($order as $o) {
      if($o['c'] > 0) {
        ModelFRM::newInstance()->updateBoardPosition($o['c'], $o['p'], $i+1);
        $i++;
      }
    }
  }

  exit;
}

osc_add_hook('ajax_admin_frm_board_position', 'frm_board_position');


// CHECK LOGGED USER
function frm_control_user($user_id, $board) {
  $user = ModelFRM::newInstance()->getUser($user_id);
  $groups = array_filter(explode(',', isset($board['s_premium_groups_ids']) ? $board['s_premium_groups_ids'] : ''));

  
  if(empty($groups)) {
    return true;
  }

  if(@$user['b_admin'] == 1) {
    return true;
  }

  if(@$user['b_moderator'] == 1) {
    return true;
  }  

  
  if(frm_check_premium()) {
    if($user_id <= 0) {
      return false;
    }
    
    $user_group = osp_get_user_group($user_id);
 
    if(in_array($user_group, $groups)) {
      return true;
    }
  }

  return false;
}


// GET PREMIUM GROUPS
function frm_premium_groups() {
  if(frm_check_premium()) {
    $groups = ModelOSP::newInstance()->getGroups();
    return $groups;
  }

  return false;
}


// CHECK IF PREMIUM GROUPS ARE SET
function frm_check_premium() {
  if(function_exists('osp_param')) {
    if(osp_param('groups_enabled') == 1) {
      return true;
    }
  }

  return false;
}


// GET BOARD PREMIUM GROUPS
function frm_board_groups($board) {
  $text = array();
  $groups = array_filter(explode(',', $board['s_premium_groups_ids']));

  if(count($groups) > 0) {
    foreach($groups as $id) {
      $group_data = ModelOSP::newInstance()->getGroup($id);
      $text[] = @$group_data['s_name'];
    }
  }

  return implode(', ', array_filter($text));
}


// HOME LINK
function frm_home() {
  return osc_route_url('frm-home'); 
}


// CLEAN POST BODY
function frm_clean_body($body) {
  $body = preg_replace('!\s+!', ' ', $body);                             // remove multiple white spaces
  return $body;
}


// UPLOAD POST ATTACHMENT
function frm_upload_attachment($topic_id, $post_id, $file) {
  $attachment = $file;
  $allowed_extensions = array('png', 'jpg', 'jpeg', 'gif', 'txt', 'pdf', 'doc', 'docx');

  $extension = strtolower(pathinfo($attachment['name'], PATHINFO_EXTENSION));
  $max_file_size = 2048 * 1000;  //(in bytes)
  $file_size = $attachment['size'];
  $file_name = date('YmdHis') . '_' . $post_id . '_' . $topic_id . '.' . $extension;

  $dir = osc_content_path() . 'uploads/forums/attachment/';
  osc_mkdir($dir);
  
  if($attachment['name'] <> '') {
    if( $attachment['error'] == UPLOAD_ERR_OK) {
      if(in_array($extension, $allowed_extensions)) {
        if( $file_size < $max_file_size ) {
          if( move_uploaded_file($attachment['tmp_name'], $dir . $file_name ) ) {
            return $file_name;

          } else {
            osc_add_flash_error_message(__('There was an error with attachment upload', 'forums') );
          }
        } else {
          osc_add_flash_error_message( __('Attachment is too big and was not uploaded. Maximum file size is:', 'forums') . ' ' . round($max_file_size/1000) . 'kb' );
        }
      } else {
        osc_add_flash_error_message( __('Your attachment extension is not allowed, file was not uploaded. Only files with following extensions are allowed', 'forums') . ': ' . implode(', ', $allowed_extensions) );
      }
    } else {
      osc_add_flash_error_message( __('An error with attachment upload has occurred, please try again.', 'forums') );
    }
  }
  
  return false;
}



// UPLOAD USER IMAGE
function frm_upload_profile_picture($user_id, $file) {
  $attachment = $file;
  $allowed_extensions = array('png', 'jpg', 'jpeg', 'gif');

  $extension = strtolower(pathinfo($attachment['name'], PATHINFO_EXTENSION));
  $max_file_size = 1024 * 1000;  //(in bytes)
  $file_size = $attachment['size'];
  $file_name = date('YmdHis') . '_' . $user_id . '.' . $extension;

  $dir = osc_content_path() . 'uploads/forums/user/';
  osc_mkdir($dir);

  if($attachment['name'] <> '') {
    if($attachment['error'] == UPLOAD_ERR_OK) {
      if(in_array($extension, $allowed_extensions)) {
        if( $file_size < $max_file_size ) {
          //if(move_uploaded_file($attachment['tmp_name'], osc_content_path() . 'plugins/forums/img/user/' . $file_name)) {
          if(move_uploaded_file($attachment['tmp_name'], $dir . $file_name)) {
            return $file_name;

          } else {
            osc_add_flash_error_message(__('There was an error with image upload', 'forums'));
          }
        } else {
          osc_add_flash_error_message(__('Image is too big and was not uploaded. Maximum file size is:', 'forums') . ' ' . round($max_file_size/1000) . 'kb');
        }
      } else {
        osc_add_flash_error_message(__('Your image extension is not allowed, file was not uploaded. Only images with following extensions are allowed', 'forums') . ': ' . implode(', ', $allowed_extensions));
      }
    } else {
      osc_add_flash_error_message(__('An error with image upload has occurred, please try again.', 'forums'));
    }
  }
  
  return false;
}


// GENERATE POST
function frm_generate_post($board, $topic, $post, $counter, $type = '', $user = -1, $logged = -1) {
  require 'form/loop-post.php';
}


// GENERATE PAGINATION
function frm_paginate($board, $topic, $user, $type, $page_id, $per_page, $items_all, $class = '') {
  $html = '';
  $term = Params::getParam('searchTerm');
  $activity_type = Params::getParam('type');

  if($per_page < $items_all) {
    $html .= '<div class="frm-pagination ' . $class . '">';

    $pages = ceil($items_all/$per_page); 
    $page_actual = ($page_id == '' ? 1 : $page_id);

    if($pages > 6) {

      // Too many pages to list them all
      if($page_id == 1) { 
        $ids = array(1,2,3, $pages);

      } else if ($page_id > 1 && $page_id < $pages) {
        $ids = array(1,$page_id-1, $page_id, $page_id+1, $pages);

      } else {
        $ids = array(1, $page_id-2, $page_id-1, $page_id);

      }

      $old = -1;
      $ids = array_unique(array_filter($ids));

      foreach($ids as $i) {
        if($type == 'topic') {
          $url = osc_route_url('frm-topic-paginate', array('topicSlug' => frm_slug($topic['s_title'], 'topic'), 'topicId' => $topic['pk_i_id'], 'pageId' => $i));
        } else if ($type == 'board') {
          $url = osc_route_url('frm-board-paginate', array('boardSlug' => frm_slug(frm_name($board), 'board'), 'boardId' => $board['pk_i_id'], 'pageId' => $i));
        } else if ($type == 'user') {
          $url = osc_route_url('frm-user-paginate', array('userSlug' => frm_slug(frm_user_name($user), 'user'), 'userId' => $user['pk_i_id'], 'pageId' => $i));
        } else if ($type == 'search') {
          $url = osc_route_url('frm-search-paginate', array('searchTerm' => $term, 'pageId' => $i));
        } else if ($type == 'activity') {
          $url = osc_route_url('frm-activity-paginate', array('type' => $activity_type, 'pageId' => $i));
        }        

        if($old <> -1 && $old <> $i - 1) {
          $html .= '<span>&middot;&middot;&middot;</span>';
        }

        $html .= '<a href="' . $url . '" ' . ($page_actual == $i ? 'class="frm-active"' : '') . '>' . $i . '</a>';
        $old = $i;
      }

    } else {

      // List all pages
      for ($i = 1; $i <= $pages; $i++) {
        if($type == 'topic') {
          $url = osc_route_url('frm-topic-paginate', array('topicSlug' => frm_slug($topic['s_title'], 'topic'), 'topicId' => $topic['pk_i_id'], 'pageId' => $i));
        } else if ($type == 'board') {
          $url = osc_route_url('frm-board-paginate', array('boardSlug' => frm_slug(frm_name($board), 'board'), 'boardId' => $board['pk_i_id'], 'pageId' => $i));
        } else if ($type == 'user') {
          $url = osc_route_url('frm-user-paginate', array('userSlug' => frm_slug(frm_user_name($user), 'user'), 'userId' => $user['pk_i_id'], 'pageId' => $i));
        } else if ($type == 'search') {
          $url = osc_route_url('frm-search-paginate', array('searchTerm' => $term, 'pageId' => $i));
        } else if ($type == 'activity') {
          $url = osc_route_url('frm-activity-paginate', array('type' => $activity_type, 'pageId' => $i));
          
        }
        $html .= '<a href="' . $url . '" ' . ($page_actual == $i ? 'class="frm-active"' : '') . '>' . $i . '</a>';
      }
    }

    $html .= '</div>';
  }

  return $html;
}


// POST MANAGE URL
function frm_post_manage_url($topic_id, $post_id, $action) {
  return osc_route_url('frm-manage-post', array('postAction' => $action, 'topicId' => $topic_id, 'postId' => $post_id));
}


// TOPIC MANAGE URL
function frm_topic_manage_url($topic_id, $action) {
  return osc_route_url('frm-manage-topic', array('topicAction' => $action, 'topicId' => $topic_id));
}


// CHECK IF USER IS ADMIN OR MODERATOR IN BOARD
function frm_check_privilege($user, $board) {
  if(osc_is_admin_user_logged_in()) {
    return true;
  }

  if(isset($user['pk_i_id']) && $user['pk_i_id'] > 0) {
    if($user['b_admin'] == 1) {
      return true;
    } else if ($user['b_moderator'] == 1) {
      if($board['s_moderators_ids'] <> '') {
        $list_users = array_filter(explode($board['s_moderators_ids'])); 
 
        if(in_array($user['pk_i_id'], $list_users)) {
          return true;
        }
      }
    }
  }

  return false;
}


// GENERATE BREADCRUMBS
function frm_breadcrumbs() {
  $board_id = Params::getParam('boardId');
  $topic_id = Params::getParam('topicId');
  $user_id = Params::getParam('userId');
  $term = Params::getParam('searchTerm');
  $type = Params::getParam('type');

  if($topic_id > 0) {
    $topic = ModelFRM::newInstance()->getTopic($topic_id);
    $board_id = $topic['fk_i_board_id'];
  }

  if($board_id > 0) {
    $board = ModelFRM::newInstance()->getBoard($board_id);
  }

  if(@$board['fk_i_parent_id'] > 0) {
    $parent_board = ModelFRM::newInstance()->getBoard($board['fk_i_parent_id']);
  }

  if($user_id > 0) {
    $user = ModelFRM::newInstance()->getUser($user_id);
  }

  $i = 1;

  $html = '<div class="frm-breadcrumbs">';
  $html .= '<i class="fa fa-home"></i>';
  $html .= '<ol itemscope itemtype="http://schema.org/BreadcrumbList">';
  $html .= '<meta itemprop="name" content="Breadcrumb">';
  
  $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
  $html .= '<a itemprop="item" href="' . osc_route_url('frm-home') . '"><span itemprop="name">' . __('Forums', 'forums') . '</span></a>';

  //if(osc_get_osclass_section() <> 'home-section' && !(osc_get_osclass_section() == 'search-section' && Params::getParam('searchTerm') == '')) {
  if(!(osc_get_osclass_section() == 'search-section' && Params::getParam('searchTerm') == '')) {
    $html .= '<span itemprop="position" content="' . $i . '">/</span>';
  }

  $html .= '</li>';
  $i++;
  
  if(osc_get_osclass_section() == 'home-section') {
    if(osc_is_web_user_logged_in()) {
      $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
      $html .= '<a itemprop="item" href="' . osc_route_url('frm-activity', array('type' => 'unread')) . '"><span itemprop="name">' . __('Unread', 'forums') . '</span></a>';
      $html .= '<span itemprop="position" content="' . $i . '">/</span>';
      $html .= '</li>';
   

      $i++;
    }
    
    $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
    $html .= '<a itemprop="item" href="' . osc_route_url('frm-activity', array('type' => 'latest')) . '"><span itemprop="name">' . __('Latest', 'forums') . '</span></a>';
    $html .= '<meta itemprop="position" content="' . $i . '">';
    $html .= '</li>';
 
    $i++;
  }


  if($term <> '') {
    $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
    $html .= '<a itemprop="item" href="' . osc_route_url('frm-search', array('searchTerm' => $term)) . '"><span itemprop="name">' . __('Search', 'forums') . '</span></a>';
    $html .= '<meta itemprop="position" content="' . $i . '">';
    $html .= '</li>';
 
    $i++;
  }

  if($type <> '') {
    $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
    $html .= '<a itemprop="item" href="' . osc_route_url('frm-activity', array('type' => $type)) . '"><span itemprop="name">' . __('Activity', 'forums') . '</span></a>';
    $html .= '<meta itemprop="position" content="' . $i . '">';
    $html .= '</li>';
 
    $i++;
  }

  if($user_id > 0) {
    $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
    $html .= '<a itemprop="item" href="' . frm_user_url($user) . '"><span itemprop="name">' . frm_user_name($user) . '</span></a>';
    $html .= '<meta itemprop="position" content="' . $i . '">';
    $html .= '</li>';
  
    $i++;
  }

  if(isset($parent_board['pk_i_id']) && $parent_board['pk_i_id'] > 0) {
    $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
    $html .= '<a itemprop="item" href="' . frm_board_url($parent_board) . '"><span itemprop="name">' . frm_name($parent_board) . '</span></a>';

    if($board_id > 0) {
      $html .= '<span itemprop="position" content="' . $i . '">/</span>';
    } else {
      $html .= '<meta itemprop="position" content="' . $i . '">';
    }

    $html .= '</li>';
  
    $i++;
  }

  if($board_id > 0) {
    $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
    $html .= '<a itemprop="item" href="' . frm_board_url($board) . '"><span itemprop="name">' . frm_name($board) . '</span></a>';

    if($topic_id > 0) {
      $html .= '<span itemprop="position" content="' . $i . '">/</span>';
    } else {
      $html .= '<meta itemprop="position" content="' . $i . '">';
    }

    $html .= '</li>';
  
    $i++;
  }
  
  if($topic_id > 0) {
    $html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
    $html .= '<a itemprop="item" href="' . frm_topic_url($topic) . '"><span itemprop="name">' . $topic['s_title'] . '</span></a>';
    $html .= '<meta itemprop="position" content="' . $i . '">';
    $html .= '</li>';
  
    $i++;
  }

  $html .= '</ol>';

  if(osc_is_web_user_logged_in()) {
    $html .= '<a href="' . osc_route_url('frm-profile', array('userId' => osc_logged_user_id())) . '" class="frm-my-profile"><i class="fa fa-user-o"></i> ' . __('My profile', 'forums') . '</a>';
  }

  $html .= '</div>';

  return $html;
}


// BOARD URL
function frm_board_url($board, $page_id = 1) {
  if($page_id == 1) {
    return osc_route_url('frm-board', array('boardSlug' => frm_slug(frm_name($board), 'board'), 'boardId' => $board['pk_i_id']));
  } else {
    return osc_route_url('frm-board-paginate', array('boardSlug' => frm_slug(frm_name($board), 'board'), 'boardId' => $board['pk_i_id'], 'pageId' => $page_id));
  }
}


// POST URL
function frm_post_url($topic, $post) {
  $page_id = ModelFRM::newInstance()->getPostPosition($topic['pk_i_id'], $post['pk_i_id']);
  return osc_route_url('frm-post-page', array('topicSlug' => frm_slug($topic['s_title'], 'topic'), 'topicId' => $topic['pk_i_id'], 'pageId' => $page_id, 'postId' => $post['pk_i_id']));
}


// TOPIC URL
function frm_topic_url($topic, $page_id = 1) {
  if($page_id == 1) {
    return osc_route_url('frm-topic', array('topicSlug' => frm_slug($topic['s_title'], 'topic'), 'topicId' => $topic['pk_i_id']));
  } else {
    return osc_route_url('frm-topic-paginate', array('topicSlug' => frm_slug($topic['s_title'], 'topic'), 'topicId' => $topic['pk_i_id'], 'pageId' => $page_id));
  }
}


// USER URL
function frm_user_url($user) {
  if(isset($user['fk_i_user_id']) && isset($user['s_name']) && $user['fk_i_user_id'] > 0) {
    return osc_route_url('frm-user', array('userSlug' => frm_slug($user['s_username'] <> '' ? $user['s_username'] : $user['s_name'], 'user'), 'userId' => $user['fk_i_user_id']));
  } else {
    return '#';
  }
}



// CREATE SLUG
function frm_slug($text, $type = '') {
  $text = trim($text);
  
  if(frm_param('sanitize') == 1) {
    $text = str_replace(' ', '-', $text);
    $text = strtolower(trim(preg_replace('/[^A-Za-z0-9-]+/', '', $text)));
  }
  
  $slug = osc_sanitizeString($text);
  
  if($slug == '') {
    if($type == 'board') {
      $slug = 'b';
    } else if ($type == 'topic') {
      $slug = 't';
    } else if ($type == 'user') {
      $slug = 'u';
    } else if($type != '') {
      $slug = substr($type, 0, 1);
    } else {
      $slug = 'f';
    }
  }

  return $slug;
}


// GET USER NAME
function frm_user_name($user) {
  if(USER_NAME_TYPE == 'OSCLASS_USERNAME') {
    if($user['pk_i_id'] != $user['s_osclass_username']) {
      return $user['s_osclass_username'];
    }
  }
  
  if(isset($user['s_username']) && $user['s_username'] <> '') {
    return $user['s_username'];
  } else if(isset($user['s_name']) && $user['s_name'] <> '') {
    return $user['s_name'];
  } else {
    return __('Unknown user', 'forums');
  }

  return $name;
}


// GET USER RANK
function frm_user_rank_circle($user) {
  $id = frm_user_rank($user, 'id');
  $html = '';

  if($id <= 0) {
    //$html .= '<i class="fa fa-circle"></i>';
    $html .= '<i class="fa fa-star"></i>';
  } else {
    for($i = 0; $i <= $id; $i++) {
      //$html .= '<i class="fa fa-circle"></i>';
      $html .= '<i class="fa fa-star"></i>';
    }
  }

  return $html;
}


// GET USER RANK DOTS
function frm_user_rank($user, $type = 'name') {
  $posts = isset($user['i_num_posts']) ? $user['i_num_posts'] : 0;
  $id = 0;
  $color = '#888';

  if(!isset($user['pk_i_id'])) {
    $color = '#777777';
    $id = 0;
    $rank = __('Unknown', 'forums');
    
  } else if($user['b_admin'] == 1) {
    $color = '#cc0000';
    $id = 7;
    $rank = __('Admin', 'forums');

  } else if ($user['b_moderator'] == 1) {
    $color = '#a7b129';
    $id = 7;
    $rank = __('Moderator', 'forums');

  } else if($posts < 10) {
    $color = '#3ea2be';
    $id = 1;
    $rank = __('Newbie', 'forums');

  } else if ($posts < 50) {
    $color = '#538dd6';
    $id = 2;
    $rank = __('Junior', 'forums');

  } else if ($posts < 100) {
    $color = '#54b051';
    $id = 3;
    $rank = __('Senior', 'forums');

  } else if ($posts < 250) {
    $color = '#e26c26';
    $id = 4;
    $rank = __('Expert', 'forums');

  } else if ($posts < 500) {
    $color = '#d62a93';
    $id = 5;
    $rank = __('Veteran', 'forums');

  } else {
    $color = '#009286';
    $id = 6;
    $rank = __('Platinum', 'forums');

  }

  if($type == 'id') {
    return $id;
  } else if($type == 'color') {
    return $color;
  } else {
    return $rank;
  }
}


// GET USER IMAGE
function frm_user_img($user) {
  $name = frm_slug(frm_user_name($user), 'USERNAME');
  $name = ($name == '' ? $user['fk_i_user_id'] : $name);
  $letter = strtolower(substr($name, 0, 1));
  
  //$dir = osc_content_path() . 'plugins/forums/img/user/';
  $path = osc_content_path() . 'uploads/forums/user/';
  $url = osc_content_url() . 'uploads/forums/user/';
  

  if(isset($user['s_image']) && $user['s_image'] <> '' && file_exists($path . $user['s_image'])) {
    return $url . $user['s_image'];
  }

  if($letter <> '') {
    $img = osc_content_url() . 'plugins/forums/img/avatar/' . $letter . '.png';
  } else {
    $img = osc_content_url() . 'plugins/forums/img/user-default.png';
  }

  return $img;
}


// CORRECT LOCALE NAME
function frm_name($data) {
  if(isset($data['locales'])) {
    if(frm_field('s_name', $data['locales']) <> '') {
      return frm_field('s_name', $data['locales']);
    }
  }

  return false;
}


// CORRECT LOCALE TITLE
function frm_title($data) {
  if(isset($data['locales'])) {
    if(frm_field('s_title', $data['locales']) <> '') {
      return frm_field('s_title', $data['locales']);
    }
  }

  return false;
}


// CORRECT LOCALE DESCRIPTION
function frm_description($data) {
  if(isset($data['locales'])) {
    if(frm_field('s_description', $data['locales']) <> '') {
      return frm_field('s_description', $data['locales']);
    }
  }

  return false;
}


// GET CORRECT LOCALE VALUE
function frm_field($column, $data, $locale = '') {
  if ($locale == '') {
    $locale = osc_current_user_locale();
  }
 
  $value = @$data[$locale][$column];

  if($value == '') {
    $value = @$data[osc_language()][$column];

    if($value == '') {
      $aLocales = osc_get_locales();
      foreach($aLocales as $locale) {
        $value = @$data[@$locale['pk_c_code']][$column];
        if($value != '') {
          break;
        }
      }
    }
  }

  return (string) $value;
}



// GET PLUGIN PARAMETER
function frm_param($name) {
  return osc_get_preference($name, 'plugin-forums');
}


// CHECK IF RUNNING ON DEMO
function frm_is_demo() {
  if(osc_logged_admin_username() == 'admin') {
    return false;
  } else if(isset($_SERVER['HTTP_HOST']) && (strpos($_SERVER['HTTP_HOST'],'mb-themes') !== false || strpos($_SERVER['HTTP_HOST'],'abprofitrade') !== false)) {
    return true;
  } else {
    return false;
  }
}


// GET CURRENT OR DEFAULT ADMIN LOCALE
function frm_get_locale() {
  $locales = OSCLocale::newInstance()->listAllEnabled();

  if(Params::getParam('frmLocale') <> '') {
    $current = Params::getParam('frmLocale');
  } else {
    $current = (osc_current_user_locale() <> '' ? osc_current_user_locale() : osc_current_admin_locale());
    $current_exists = false;

    // check if current locale exist in front-office
    foreach($locales as $l) {
      if($current == $l['pk_c_code']) {
        $current_exists = true;
      }
    }

    if(!$current_exists) {
      $i = 0;
      foreach($locales as $l) {
        if($i==0) {
          $current = $l['pk_c_code'];
        }

        $i++;
      }
    }
  }

  return $current;
}


// CREATE LOCALE SELECT BOX
function frm_locale_box($file, $param = '', $id = -1) {
  $html = '';
  $locales = OSCLocale::newInstance()->listAllEnabled();
  $current = frm_get_locale();

  if($id > 0 && $param <> '') {
    $id_string = '&' . $param . '=' . $id;
  } else {
    $id_string = '';
  }

  $html .= '<select rel="' . osc_admin_base_url(true) . '?page=plugins&action=renderplugin&file=forums/admin/' . $file . $id_string . '" class="mb-select mb-select-locale" id="frmLocale" name="frmLocale">';

  foreach($locales as $l) {
    $html .= '<option value="' . $l['pk_c_code'] . '" ' . ($current == $l['pk_c_code'] ? 'selected="selected"' : '') . '>' . $l['s_name'] . '</option>';
  }
 
  $html .= '</select>';
  return $html;
}



// CORE FUNCTIONS
if(!function_exists('mb_param_update')) {
  function mb_param_update($param_name, $update_param_name, $type = NULL, $plugin_var_name = NULL) {
  
    $val = '';
    if($type == 'check') {

      // Checkbox input
      if(Params::getParam($param_name) == 'on') {
        $val = 1;
      } else {
        if(Params::getParam($update_param_name) == 'done') {
          $val = 0;
        } else {
          $val = (osc_get_preference($param_name, $plugin_var_name) != '') ? osc_get_preference($param_name, $plugin_var_name) : '';
        }
      }
    } else {

      // Other inputs (text, pasword, ...)
      if(Params::getParam($update_param_name) == 'done' && Params::existParam($param_name)) {
        $val = Params::getParam($param_name);
      } else {
        $val = (osc_get_preference($param_name, $plugin_var_name) != '') ? osc_get_preference($param_name, $plugin_var_name) : '';
      }
    }


    // If save button was presed, update param
    if(Params::getParam($update_param_name) == 'done') {

      if(osc_get_preference($param_name, $plugin_var_name) == '') {
        osc_set_preference($param_name, $val, $plugin_var_name, 'STRING');  
      } else {
        $dao_preference = new Preference();
        $dao_preference->update(array("s_value" => $val), array("s_section" => $plugin_var_name, "s_name" => $param_name));
        osc_reset_preferences();
        unset($dao_preference);
      }
    }

    return $val;
  }
}



if(!function_exists('mesage_ok')) {
  function mesage_ok($text) {
    $final  = '<div clas="flashmesage flashmesage-ok flashmesage-inline">';
    $final .= $text;
    $final .= '</div>';
    echo $final;
  }
}


if(!function_exists('mesage_error')) {
  function mesage_error($text) {
    $final  = '<div clas="flashmesage flashmesage-error flashmesage-inline">';
    $final .= $text;
    $final .= '</div>';
    echo $final;
  }
}


if(!function_exists('osc_is_contact_page')) {
  function osc_is_contact_page() {
    $location = Rewrite::newInstance()->get_location();
    $section = Rewrite::newInstance()->get_section();
    if($location == 'contact') {
      return true ;
    }

    return false ;
  }
}


// COOKIES WORK
if(!function_exists('mb_set_cookie')) {
  function mb_set_cookie($name, $val) {
    Cookie::newInstance()->set_expires(86400 * 30);
    Cookie::newInstance()->push($name, $val);
    Cookie::newInstance()->set();
  }
}


if(!function_exists('mb_get_cookie')) {
  function mb_get_cookie($name) {
    return Cookie::newInstance()->get_value($name);
  }
}

if(!function_exists('mb_drop_cookie')) {
  function mb_drop_cookie($name) {
    Cookie::newInstance()->pop($name);
  }
}

if(!function_exists('osc_content_url')) {
  function osc_content_url() {
    return osc_base_url() . 'oc-content/';
  }
}

?>