<?php
class ModelFRM extends DAO {
private static $instance;

public static function newInstance() {
  if( !self::$instance instanceof self ) {
    self::$instance = new self;
  }
  return self::$instance;
}

function __construct() {
  parent::__construct();
}

public function getTable_category() {
  return DB_TABLE_PREFIX.'t_frm_category';
}

public function getTable_category_locale() {
  return DB_TABLE_PREFIX.'t_frm_category_locale';
}

public function getTable_board() {
  return DB_TABLE_PREFIX.'t_frm_board';
}

public function getTable_board_read() {
  return DB_TABLE_PREFIX.'t_frm_board_read';
}

public function getTable_board_locale() {
  return DB_TABLE_PREFIX.'t_frm_board_locale';
}

public function getTable_topic() {
  return DB_TABLE_PREFIX.'t_frm_topic';
}

public function getTable_topic_read() {
  return DB_TABLE_PREFIX.'t_frm_topic_read';
}

public function getTable_post() {
  return DB_TABLE_PREFIX.'t_frm_post';
}

public function getTable_user() {
  return DB_TABLE_PREFIX.'t_frm_user';
}

public function getTable_osclass_user() {
  return DB_TABLE_PREFIX.'t_user';
}



public function import($file) {
  $path = osc_plugin_resource($file);
  $sql = file_get_contents($path);

  if(!$this->dao->importSQL($sql) ){
    throw new Exception("Error importSQL::ModelFRM<br>" . $file . "<br>" . $this->dao->getErrorLevel() . " - " . $this->dao->getErrorDesc() );
  }
}


public function install($version = '') {
  if($version == '') {
    $this->import('forums/model/struct.sql');

    osc_set_preference('version', 100, 'plugin-forums', 'INTEGER');
  }
}


public function uninstall() {
  // DELETE ALL TABLES
  $this->dao->query(sprintf('DROP TABLE %s', $this->getTable_category()));
  $this->dao->query(sprintf('DROP TABLE %s', $this->getTable_category_locale()));
  $this->dao->query(sprintf('DROP TABLE %s', $this->getTable_board()));
  $this->dao->query(sprintf('DROP TABLE %s', $this->getTable_board_locale()));
  $this->dao->query(sprintf('DROP TABLE %s', $this->getTable_topic()));
  $this->dao->query(sprintf('DROP TABLE %s', $this->getTable_post()));
  $this->dao->query(sprintf('DROP TABLE %s', $this->getTable_user()));


  // DELETE ALL PREFERENCES
  $db_prefix = DB_TABLE_PREFIX;
  $query = "DELETE FROM {$db_prefix}t_preference WHERE s_section = 'plugin-forums'";
  $this->dao->query($query);
}



// GET CATEGORIES
public function getCategories() {
  $this->dao->select();
  $this->dao->from($this->getTable_category());
  $this->dao->orderby('i_order ASC, pk_i_id ASC');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();

    $j = 0;
    if(count($data) > 0) {
      foreach($data as $d) {
        $data[$j]['locales'] = $this->getCategoryLocales($d['pk_i_id']);
        $j++;
      }
    }

    return $data;
  }

  return array();
}


// GET CATEGORY
public function getCategory($id) {
  if($id <= 0) { return false; }
  
  $this->dao->select();
  $this->dao->from($this->getTable_category());
  $this->dao->where('pk_i_id', $id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();
    $data['locales'] = $this->getCategoryLocales($data['pk_i_id']);

    return $data;
  }

  return false;
}


// GET CATEGORY LOCALES
public function getCategoryLocales($id) {
  $this->dao->select();
  $this->dao->from($this->getTable_category_locale());
  $this->dao->where('fk_i_category_id', $id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    $output = array();

    if(count($data) > 0) {
      foreach($data as $d) {
        $output[$d['fk_c_locale_code']] = array('s_name' => $d['s_name']);
      }
    }

    return $output;
  }

  return array();
}



// GET BOARDS
public function getBoards($category_id = '', $parent_id = '') {
  $this->dao->select('b.*, coalesce(br.i_viewed, 0) as i_viewed');
  $this->dao->from($this->getTable_board() . ' as b');
  $this->dao->join($this->getTable_board_read() . ' as br', '(b.pk_i_id = br.fk_i_board_id AND br.fk_i_user_id = "' . osc_logged_user_id() . '")', 'LEFT OUTER');

  $this->dao->orderby('b.i_order ASC, b.pk_i_id ASC');

  if($category_id > 0) {
    $this->dao->where('b.fk_i_category_id', $category_id);
  }

  if($parent_id > 0) {
    $this->dao->where('b.fk_i_parent_id', $parent_id);
  } else if($parent_id == '') {
    $this->dao->where('(b.fk_i_parent_id is null OR b.fk_i_parent_id = 0)');
  }

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();

    $j = 0;
    if(count($data) > 0) {
      foreach($data as $d) {
        if($category_id > 0) {
          $data[$j]['children'] = $this->getBoards($category_id, $d['pk_i_id']);
        }

        $data[$j]['locales'] = $this->getBoardLocales($d['pk_i_id']);
        $j++;
      }
    }

    return $data;
  }

  return array();
}



// COUNT CATEGORY BOARDS
public function countCategoryBoards($category_id = '') {
  $this->dao->select('count(pk_i_id) as i_count');
  $this->dao->from($this->getTable_board());

  if($category_id > 0) {
    $this->dao->where('fk_i_category_id', $category_id);
  }

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();

    if($data['i_count'] > 0) {
      return $data['i_count'];
    }
  }

  return 0;
}


// COUNT USER POSTS
public function countUserPosts($user_id) {
  $this->dao->select('count(pk_i_id) as i_count');
  $this->dao->from($this->getTable_post());

  $this->dao->where('fk_i_user_id', $user_id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();

    if($data['i_count'] > 0) {
      return $data['i_count'];
    }
  }

  return 0;
}


// COUNT TOPIC POSTS
public function countTopicPosts($topic_id) {
  $this->dao->select('count(pk_i_id) as i_count');
  $this->dao->from($this->getTable_post());

  $this->dao->where('fk_i_topic_id', $topic_id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();

    if($data['i_count'] > 0) {
      return $data['i_count'];
    }
  }

  return 0;
}


// COUNT BOARD POSTS
public function countBoardPosts($board_ids) {
  $this->dao->select('sum(coalesce(i_num_posts, 0)) as i_count');
  $this->dao->from($this->getTable_topic());
 
  $this->dao->where('fk_i_board_id in (' . $board_ids . ')');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();

    if($data['i_count'] > 0) {
      return $data['i_count'];
    }
  }

  return 0;
}


// COUNT BOARD TOPICS
public function countBoardTopics($board_ids) {
  $this->dao->select('count(pk_i_id) as i_count');
  $this->dao->from($this->getTable_topic());

  $this->dao->where('fk_i_board_id in (' . $board_ids . ')');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();

    if($data['i_count'] > 0) {
      return $data['i_count'];
    }
  }

  return 0;
}



// GET BOARD CHILDRENS
public function getBoardChildren($board_id) {
  $this->dao->select('pk_i_id');
  $this->dao->from($this->getTable_board());
  $this->dao->where('fk_i_parent_id', $board_id);

  $result = $this->dao->get();
  $output = array();

  if($result) {
    $data = $result->result();

    if(count($data) > 0) {
      $data = array_column($data, 'pk_i_id');
      $output = array_merge($output, $data);

      foreach($data as $d) {
        $output = array_merge($output, $this->getBoardChildrenHelp($d));
      }
    }

    return array_filter($output);
  }

  return array();
}


// GET BOARD CHILDRENS HELP
public function getBoardChildrenHelp($board_id) {
  $this->dao->select('pk_i_id');
  $this->dao->from($this->getTable_board());
  $this->dao->where('fk_i_parent_id', $board_id);

  $result = $this->dao->get();

  if($result) {
    $data = $result->result();

    if(count($data) > 0) {
      $data = array_column($data, 'pk_i_id');

      foreach($data as $d) {
        $data = array_merge($data, $this->getBoardChildrenHelp($d));
      }

      return $data;
    }

    return array_filter($data);
  }

  return array();
}



// COUNT USER TOPICS
public function countUserTopics($user_id) {
  $this->dao->select('count(pk_i_id) as i_count');
  $this->dao->from($this->getTable_topic());

  $this->dao->where('fk_i_user_id', $user_id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();

    if($data['i_count'] > 0) {
      return $data['i_count'];
    }
  }

  return 0;
}




// GET BOARD
public function getBoard($id) {
  if($id <= 0) { return false; }
  
  $this->dao->select();
  $this->dao->from($this->getTable_board());
  $this->dao->where('pk_i_id', $id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();
    $data['locales'] = $this->getBoardLocales($data['pk_i_id']);

    return $data;
  }

  return false;
}


// GET BOARD LOCALES
public function getBoardLocales($id) {
  if($id <= 0) { return array(); }
  
  $this->dao->select();
  $this->dao->from($this->getTable_board_locale());
  $this->dao->where('fk_i_board_id', $id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    $output = array();

    if(count($data) > 0) {
      foreach($data as $d) {
        $output[$d['fk_c_locale_code']] = array('s_name' => $d['s_name'], 's_description' => $d['s_description']);
      }
    }

    return $output;
  }

  return array();
}


// GET TOPIC
public function getTopic($id) {
  if($id <= 0) { return false; }
  
  $this->dao->select();
  $this->dao->from($this->getTable_topic());
  $this->dao->where('pk_i_id', $id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();
    return $data;
  }

  return false;
}


// GET TOPICS
public function getTopics($board_id, $limit = array()) {
  $this->dao->select('t.*, coalesce(tr.i_viewed, 0) as i_viewed, max(coalesce(p.dt_created, t.dt_created)) as dt_last_activity');
  $this->dao->from($this->getTable_topic() . ' as t');
  $this->dao->join($this->getTable_topic_read() . ' as tr', '(t.fk_i_board_id = tr.fk_i_board_id AND t.pk_i_id = tr.fk_i_topic_id AND tr.fk_i_user_id = "' . osc_logged_user_id() . '")', 'LEFT OUTER');
  $this->dao->join($this->getTable_post() . ' as p', '(t.pk_i_id = p.fk_i_topic_id)', 'LEFT OUTER');

  $this->dao->where('t.fk_i_board_id', $board_id);
  $this->dao->groupby('t.pk_i_id');
  //$this->dao->orderby('t.b_sticky DESC, t.dt_created DESC');
  $this->dao->orderby('t.b_sticky DESC, dt_last_activity DESC');


  // $limit[0] == limit; $limit[1] == page
  $page = (isset($limit[1]) ? $limit[1] : 0);
  $per_page = (isset($limit[0]) ? $limit[0] : frm_param('topics_per_page'));

  if($page > 0) {
    $this->dao->limit(($page-1)*$per_page, $per_page);
  } else {
    $this->dao->limit($per_page);
  }


  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}


// GET LAST ACTIVE TOPICS
public function getLastActiveTopics($limit = 5) {
  $this->dao->select('t.*, max(coalesce(p.dt_created, t.dt_created)) as dt_last_activity');
  $this->dao->from($this->getTable_topic() . ' as t');
  $this->dao->join($this->getTable_post() . ' as p', '(t.pk_i_id = p.fk_i_topic_id)', 'LEFT OUTER');

  $this->dao->groupby('t.pk_i_id');
  $this->dao->orderby('dt_last_activity DESC');

  $this->dao->limit($limit);
  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}


// GET MOST RECENT TOPICS
public function getLastCreatedTopics($limit = 5) {
  $this->dao->select();
  $this->dao->from($this->getTable_topic());
  $this->dao->orderby('dt_created DESC');

  $this->dao->limit($limit);
  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}


// GET POSTS
public function getPosts($topic_id, $limit = array()) {
  $this->dao->select();
  $this->dao->from($this->getTable_post());
  $this->dao->where('fk_i_topic_id', $topic_id);
  $this->dao->orderby('dt_created ASC');

  // $limit[0] == limit; $limit[1] == page
  $page = (isset($limit[1]) ? $limit[1] : 0);
  $per_page = (isset($limit[0]) ? $limit[0] : frm_param('posts_per_page'));

  if($page > 0) {
    $this->dao->limit(($page-1)*$per_page, $per_page);
  } else {
    $this->dao->limit($per_page);
  }


  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}


// GET MOST RECENT POSTS
public function getLastPosts($limit = 5) {
  $this->dao->select();
  $this->dao->from($this->getTable_post());
  $this->dao->orderby('dt_created DESC');

  $this->dao->limit($LIMIT);
  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}


// GET POSTS
public function getPostPosition($topic_id, $post_id) {
  $per_page = frm_param('topics_per_page');

  $this->dao->select('pk_i_id');
  $this->dao->from($this->getTable_post());
  $this->dao->where('fk_i_topic_id', $topic_id);
  $this->dao->orderby('dt_created ASC');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    $ids = array_column($data, 'pk_i_id');
    $id_position = array_search($post_id, $ids);

    $found_page = ceil(($id_position+1)/$per_page);

    return $found_page;
  }

  return false;
}




// GET POSTS
public function getPostsWithFile($topic_id) {
  $this->dao->select();
  $this->dao->from($this->getTable_post());
  $this->dao->where('fk_i_topic_id', $topic_id);
  $this->dao->where('(s_file is not null AND s_file <> "")');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}



// GET POSTS BY USER ID
public function getPostsByUser($user_id, $limit = array()) {
  $this->dao->select();
  $this->dao->from($this->getTable_post());
  $this->dao->where('fk_i_user_id', $user_id);
  $this->dao->orderby('dt_created DESC');

  // $limit[0] == limit; $limit[1] == page
  $page = (isset($limit[1]) ? $limit[1] : 0);
  $per_page = (isset($limit[0]) ? $limit[0] : frm_param('posts_per_page'));

  if($page > 0) {
    $this->dao->limit(($page-1)*$per_page, $per_page);
  } else {
    $this->dao->limit($per_page);
  }


  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}


// GET POSTS BY SEARCH TERM
public function getPostsBySearchTerm($term, $limit = array()) {
  $this->dao->select();
  $this->dao->from($this->getTable_post());
  $this->dao->where('s_body like "%' . $term . '%"');
  $this->dao->orderby('dt_created DESC');

  // $limit[0] == limit; $limit[1] == page
  $page = (isset($limit[1]) ? $limit[1] : 0);
  $per_page = (isset($limit[0]) ? $limit[0] : frm_param('posts_per_page'));

  if($page > 0) {
    $this->dao->limit(($page-1)*$per_page, $per_page);
  } else {
    $this->dao->limit($per_page);
  }


  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}




// GET POSTS BY SEARCH TERM
public function getPostsByActivityType($type, $limit = array()) {
  $this->dao->select('p.*');
  $this->dao->from($this->getTable_post() . ' as p');
  $this->dao->orderby('p.dt_created DESC');
  
  if($type == 'unread' && osc_is_web_user_logged_in()) {
    $this->dao->join($this->getTable_topic_read() . ' as tr', '(p.fk_i_topic_id = tr.fk_i_topic_id AND tr.fk_i_user_id = "' . osc_logged_user_id() . '")', 'LEFT OUTER');
    $this->dao->where('coalesce(tr.i_viewed, 0) != 1');
  }

  // $limit[0] == limit; $limit[1] == page
  $page = (isset($limit[1]) ? $limit[1] : 0);
  $per_page = (isset($limit[0]) ? $limit[0] : frm_param('posts_per_page'));

  if($page > 0) {
    $this->dao->limit(($page-1)*$per_page, $per_page);
  } else {
    $this->dao->limit($per_page);
  }


  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}



// COUNT POSTS BY SEARCH TERM
public function countPostsBySearchTerm($term) {
  $this->dao->select('count(pk_i_id) as i_count');
  $this->dao->from($this->getTable_post());
  $this->dao->where('s_body like "%' . $term . '%"');


  $result = $this->dao->get();
  
  if($result) {
    $count = $result->row()['i_count'];
    return $count;
  }

  return 0;
}


// COUNT POSTS BY ACTIVITY TYPE
public function countPostsByActivityType($type) {
  $this->dao->select('count(pk_i_id) as i_count');
  $this->dao->from($this->getTable_post() . ' as p');

  if($type == 'unread' && osc_is_web_user_logged_in()) {
    $this->dao->join($this->getTable_topic_read() . ' as tr', '(p.fk_i_topic_id = tr.fk_i_topic_id AND tr.fk_i_user_id = "' . osc_logged_user_id() . '")', 'LEFT OUTER');
    $this->dao->where('coalesce(tr.i_viewed, 0) != 1');
  }
  
  $result = $this->dao->get();
  
  if($result) {
    $count = $result->row()['i_count'];
    return $count;
  }

  return 0;
}




// GET POST
public function getPost($post_id) {
  if($post_id <= 0) { return false; }
  
  $this->dao->select();
  $this->dao->from($this->getTable_post());
  $this->dao->where('pk_i_id', $post_id);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row();
    return $data;
  }

  return false;
}



// GET USER
public function getUser($id) {
  if($id <= 0) { return false; }
  
  $this->dao->select('ou.pk_i_id, ou.s_name, ou.s_email, ou.dt_reg_date, ou.s_username as s_osclass_username, u.*');
  $this->dao->from($this->getTable_osclass_user() . ' as ou');
  $this->dao->join($this->getTable_user() . ' as u', 'ou.pk_i_id = u.fk_i_user_id', 'LEFT OUTER');

  if(is_numeric($id)) {
    $this->dao->where('pk_i_id', $id);
  } else {
    $this->dao->where('ou.s_email', $id);
  }

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->row(); 
    return $data;
  }

  return false;
}


// GET USERS
public function getUsers($ids) {
  $this->dao->select('ou.pk_i_id, ou.s_name, ou.s_email, ou.dt_reg_date, ou.s_username as s_osclass_username, u.*');
  $this->dao->from($this->getTable_osclass_user() . ' as ou');
  $this->dao->join($this->getTable_user() . ' as u', 'ou.pk_i_id = u.fk_i_user_id', 'LEFT OUTER');

  $this->dao->limit(6);
  $this->dao->where('pk_i_id in (' . $ids . ')');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result(); 
    $output = array();

    if(count($data) > 0) {
      foreach($data as $d) {
        $output[$d['pk_i_id']] = $d;
      }
    }

    return $output;
  }

  return array();
}


// GET USERS
public function getStatUsers() {
  $this->dao->select('fk_i_user_id');
  $this->dao->from($this->getTable_user());

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result(); 
    return $data;
  }

  return array();
}



// GET USERS
public function getModeratorUsers() {
  $this->dao->select('ou.pk_i_id, ou.s_name, ou.s_email, ou.dt_reg_date, ou.s_username as s_osclass_username, u.*');
  $this->dao->from($this->getTable_osclass_user() . ' as ou');
  $this->dao->join($this->getTable_user() . ' as u', 'ou.pk_i_id = u.fk_i_user_id', 'INNER');

  $this->dao->where('u.b_moderator', 1);

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result(); 
    return $data;
  }

  return array();
}


// GET USERS
public function getSuperUsers() {
  $this->dao->select('ou.pk_i_id, ou.s_name, ou.s_email, ou.dt_reg_date, ou.s_username as s_osclass_username, u.*');
  $this->dao->from($this->getTable_osclass_user() . ' as ou');
  $this->dao->join($this->getTable_user() . ' as u', 'ou.pk_i_id = u.fk_i_user_id', 'INNER');

  $this->dao->where('(u.b_moderator = 1 OR u.b_admin = 1)');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result(); 
    return $data;
  }

  return array();
}



// GET FORUM USERS
public function getForumUsers() {
  $this->dao->select();
  $this->dao->from($this->getTable_user());
  $this->dao->limit(5000);
  $this->dao->orderby('dt_last_active DESC, dt_registered DESC');

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result(); 
    return $data;
  }

  return array();
}


// UPDATE TOPIC CHARACTERISTICS
public function updateTopicSpecial($topic_id, $action) {
  if($action == 'stick') {
    return $this->dao->query('UPDATE '.$this->getTable_topic().' SET b_sticky = (coalesce(b_sticky, 0)-1)*(-1) WHERE pk_i_id=' . $topic_id);

  } else if($action == 'lock') {
    return $this->dao->query('UPDATE '.$this->getTable_topic().' SET b_locked = (coalesce(b_locked, 0)-1)*(-1), fk_i_locked_by = ' . osc_logged_user_id() . ', dt_locked_date = "' . date('Y-m-d H:i:s') . '" WHERE pk_i_id=' . $topic_id);

  } else if($action == 'solve') {
    return $this->dao->query('UPDATE '.$this->getTable_topic().' SET b_solved = (coalesce(b_solved, 0)-1)*(-1), fk_i_solved_by = ' . osc_logged_user_id() . ', dt_solved_date = "' . date('Y-m-d H:i:s') . '" WHERE pk_i_id=' . $topic_id);

  }
}


// REMOVE TOPIC
public function removeTopic($id) {
  $topic = $this->getTopic($id);

  $this->updateBoardStats($topic['fk_i_board_id'], 'topic', -1);
  $this->updateBoardStats($topic['fk_i_board_id'], 'post', -$topic['i_num_posts']);
  $this->updateUserStats(osc_logged_user_id(), 'topic', -1);
  $this->updateUserStats(osc_logged_user_id(), 'post', -$topic['i_num_posts']);

  $post_files = $this->getPostsWithFile($id);

  if(count($post_files) > 0) {
    foreach($post_files as $p) {
      $file = osc_content_path() . 'plugins/forums/attachment/' . $p['s_file'];

      if($p['s_file'] <> '' && file_exists($file) && !is_dir($file)) {
        @unlink($file);
      }
    }
  }

  $this->removePostsByTopicId($id);
  $this->dao->delete($this->getTable_topic(), array('pk_i_id' => $id));
}



// REMOVE CATEGORY
public function removeCategory($id) {
  $boards = $this->getBoards($id);

  if(is_array($boards) && count($boards) > 0) {
    foreach($boards as $b) {
      $this->removeBoard($b['pk_i_id']);
    }
  }


  $this->dao->delete($this->getTable_category(), array('pk_i_id' => $id));
  $this->dao->delete($this->getTable_category_locale(), array('fk_i_category_id' => $id));
}


// REMOVE CATEGORY
public function removeBoard($id) {
  $topics = $this->getTopics($id);

  if(is_array($topics) && count($topics) > 0) {
    foreach($topics as $t) {
      $this->removeTopic($t['pk_i_id']);
    }
  }


  $this->dao->delete($this->getTable_board(), array('pk_i_id' => $id));
  $this->dao->delete($this->getTable_board_locale(), array('fk_i_board_id' => $id));
}



// UPDATE POST CHARACTERISTICS
public function updatePostSpecial($topic_id, $post_id, $action) {
  if($action == 'best') {
    return $this->dao->query('UPDATE '.$this->getTable_topic().' SET fk_i_answer_post_id = ' . $post_id . ' WHERE pk_i_id=' . $topic_id);

  }
}


// REMOVE USER
public function removeUser($id) {
  return $this->dao->delete($this->getTable_user(), array('fk_i_user_id' => $id));
}


// REMOVE POST
public function removePost($id) {
  return $this->dao->delete($this->getTable_post(), array('pk_i_id' => $id));
}


// REMOVE POSTS BY TOPIC ID
public function removePostsByTopicId($topic_id) {
  return $this->dao->delete($this->getTable_post(), array('fk_i_topic_id' => $topic_id));
}


// INSERT POST
public function insertPost($board, $topic, $message, $attachment = array()) {
  $data = array(
    'fk_i_topic_id' => $topic['pk_i_id'],
    'fk_i_board_id' => $board['pk_i_id'],
    'fk_i_user_id' => osc_logged_user_id(),
    's_body' => $message,
    'dt_created' => date('Y-m-d H:i:s')
  );

  $this->dao->insert($this->getTable_post(), $data);
  $id = $this->dao->insertedId();

  // Upload attachment
  if(!empty($attachment) && isset($attachment['name'])) {
    $file_name = frm_upload_attachment($topic['pk_i_id'], $id, $attachment);

    if($file_name) {
      $this->updatePostFile($id, $file_name);
    }
  }


  $this->updateTopicStats($topic, 'post', 1);
  $this->updateTopicLastPostDate($topic['pk_i_id']);
  $this->updateTopicLastUser($topic['pk_i_id'], osc_logged_user_id());
  //$this->updateUserStats(osc_logged_user_id(), 'post', 1);  // already included in updateTopicStats


  $users = explode(',', $topic['s_active_users_ids']);
  $users[] = osc_logged_user_id();

  $users_list = implode(',', array_unique(array_filter(array_map('trim', $users))));

  $this->updateTopicActiveUsers($users_list, $topic['pk_i_id']);
  $this->updateUserLastActiveDate(osc_logged_user_id());
  $this->updateBoardLastTopic($board, $topic);
  
  $this->deleteTopicRead($board['pk_i_id'], $topic['pk_i_id']);
  $this->deleteBoardRead($board['pk_i_id'], $topic['pk_i_id']);

  return $id;
}



// UPDATE-INSERT CATEGORY
public function updateCategory($id, $name, $locale) {
  if($locale == '') {
    $locale = frm_get_locale();
  }


  $data_locale = array(
    'fk_c_locale_code' => $locale,
    's_name' => $name
  );


  if($id < 0) {
    $this->dao->insert($this->getTable_category(), array('i_order' => 9999));
    $id = $this->dao->insertedId();
  }

  // ensure placeholder is not considered
  if($id > 0) {
    $data_locale['fk_i_category_id'] = $id;
    $this->dao->replace($this->getTable_category_locale(), $data_locale);
    return $id;
  }
}



// UPDATE-INSERT BOARD
public function updateBoard($id, $data, $data_locale) {

  if($id < 0) {
    $data['i_order'] = 9999;
    $this->dao->insert($this->getTable_board(), $data);
    $id = $this->dao->insertedId();
  } else {
    $this->dao->update($this->getTable_board(), $data, array('pk_i_id' => $id));

    if(isset($data['fk_i_category_id'])) {
      $this->updateBoardsCategoryByParent($id, $data['fk_i_category_id']);
    }
  }

  // ensure placeholder is not considered
  if($id > 0) {
    $data_locale['fk_i_board_id'] = $id;
    $this->dao->replace($this->getTable_board_locale(), $data_locale);
    return $id;
  }
}


// UPDATE BOARDS CATEGORY BY PARENT
public function updateBoardsCategoryByParent($board_id, $category_id) {
  if($board_id > 0) {
    $this->dao->update($this->getTable_board(), array('fk_i_category_id' => $category_id), array('fk_i_parent_id' => $board_id));
  }
}



// UPDATE LAST TOPIC ON BOARD
public function updateBoardLastTopic($board, $topic) {
  $data = array(
    'fk_i_last_topic_id' => $topic['pk_i_id'],
    'fk_i_last_user_id' => $topic['fk_i_user_id'],
    'dt_last_post_date' => date('Y-m-d H:i:s')
  );

  $this->dao->update($this->getTable_board(), $data, array('pk_i_id' => $board['pk_i_id']));
}


// UPDATE BOARD READ
public function updateBoardRead($user_id, $board_id) {
  $data = array(
    'fk_i_user_id' => $user_id,
    'fk_i_board_id' => $board_id,
    'i_viewed' => 1
  );

  $this->dao->replace($this->getTable_board_read(), $data);
}


// UPDATE TOPIC READ
public function updateTopicRead($user_id, $board_id, $topic_id) {
  $data = array(
    'fk_i_user_id' => $user_id,
    'fk_i_board_id' => $board_id,
    'fk_i_topic_id' => $topic_id,
    'i_viewed' => 1
  );

  $this->dao->replace($this->getTable_topic_read(), $data);
}


// DELETE BOARD READ
public function deleteBoardRead($board_id, $user_id = '') {
  if($user_id > 0) {
    $this->dao->delete($this->getTable_board_read(), array('fk_i_user_id' => $user_id, 'fk_i_board_id' => $board_id));
  } else {
    $this->dao->delete($this->getTable_board_read(), array('fk_i_board_id' => $board_id));
  }
}


// DELETE TOPIC READ
public function deleteTopicRead($board_id, $topic_id, $user_id = '') {
  if($user_id > 0) { 
    $this->dao->delete($this->getTable_board_read(), array('fk_i_user_id' => $user_id, 'fk_i_board_id' => $board_id, 'fk_i_topic_id' => $topic_id));
  } else {
    $this->dao->delete($this->getTable_board_read(), array('fk_i_board_id' => $board_id, 'fk_i_topic_id' => $topic_id));
  }
}


// UPDATE POST
public function updatePost($board, $topic, $post, $message, $attachment = array()) {
  $data = array(
    'pk_i_id' => $post['pk_i_id'],
    'fk_i_topic_id' => $topic['pk_i_id'],
    'fk_i_board_id' => $board['pk_i_id'],
    's_body' => $message,
    'fk_i_modified_by' => osc_logged_user_id(),
    'dt_modified_date' => date('Y-m-d H:i:s')
  );


  // Upload attachment
  if(!empty($attachment) && isset($attachment['name'])) {
    $file_name = frm_upload_attachment($topic['pk_i_id'], $post['pk_i_id'], $attachment);

    if($file_name && isset($post['s_file']) && $post['s_file'] != '') {
      @unlink(osc_content_path() . 'plugins/forums/attachment/' . $post['s_file']);
      $data['s_file'] = $file_name;
    }
  }

  $this->dao->update($this->getTable_post(), $data, array('pk_i_id' => $post['pk_i_id']));
}


// UPDATE USER PROFILE
public function updateUser($data, $file = array()) {
  if(!isset($data['fk_i_user_id']) || $data['fk_i_user_id'] <= 0) {
    return false;
  }
  
  // Upload image file
  if(!empty($file) && isset($file['name'])) {
    $uploaded_file_name = frm_upload_profile_picture($data['fk_i_user_id'], $file);

    if($uploaded_file_name !== false) {

      // Remove old file
      if($data['s_image'] <> '' && file_exists(osc_content_path() . 'uploads/forums/user/' . $data['s_image'])) {
        @unlink(osc_content_path() . 'uploads/forums/user/' . $data['s_image']);
      }
      
      $data['s_image'] = $uploaded_file_name;
    }
  }

  $this->dao->update($this->getTable_user(), $data, array('fk_i_user_id' => $data['fk_i_user_id']));
}




// UPDATE POST FILE
public function updatePostFile($post_id, $file_name) {
  $this->dao->update($this->getTable_post(), array('s_file' => $file_name), array('pk_i_id' => $post_id));
}


// INSERT POST
public function insertTopic($board, $title) {
  $data = array(
    'fk_i_board_id' => $board['pk_i_id'],
    'fk_i_user_id' => osc_logged_user_id(),
    's_title' => $title,
    'i_num_posts' => 0,
    'dt_last_post_date' => date('Y-m-d H:i:s'),
    'dt_created' => date('Y-m-d H:i:s')
  );

  $this->dao->insert($this->getTable_topic(), $data);
  $id = $this->dao->insertedId();

  $this->updateBoardStats($board['pk_i_id'], 'topic', 1);
  $this->updateUserStats(osc_logged_user_id(), 'topic', 1);

  return $id;
}


// INSERT USER
public function insertUser($user_id, $name = '') {
  $data = array(
    'fk_i_user_id' => $user_id,
    'dt_last_active' => date('Y-m-d H:i:s'),
    'dt_registered' => date('Y-m-d H:i:s')
  );
  
  if(trim($name) != '') {
    $data['s_username'] = $name;
  }

  $this->dao->insert($this->getTable_user(), $data);
  $id = $this->dao->insertedId();

  return $id;
}


// UPDATE TOPIC STATS
public function updateUserLastActiveDate($user_id) {
  $this->dao->query('UPDATE '.$this->getTable_user().' SET dt_last_active = "' . date('Y-m-d H:i:s') . '" WHERE fk_i_user_id=' . $user_id);
}


// UPDATE TOPIC STATS
public function updateTopicStats($topic, $type, $value) {
  $topic_id = $topic['pk_i_id'];

  if($type == 'post') {
    $column = 'i_num_posts';
  } else {
    $column = 'i_num_views';
  }

  $this->dao->query('UPDATE '.$this->getTable_topic().' SET ' . $column . ' = coalesce(' . $column . ', 0) + (' . $value . ') WHERE pk_i_id=' . $topic_id);

  if($type == 'post') {
    $this->updateBoardStats($topic['fk_i_board_id'], $type, $value);
    $this->updateUserStats($topic['fk_i_user_id'], $type, $value);
  }
}


// UPDATE BOARD STATS
public function updateBoardStats($board_id, $type, $value) {
  if($type == 'topic') {
    $column = 'i_num_topics';
  } else {
    $column = 'i_num_posts';
  }

  $this->dao->query('UPDATE '.$this->getTable_board().' SET ' . $column . ' = coalesce(' . $column . ', 0) + (' . $value . ') WHERE pk_i_id=' . $board_id);


  // in case it is child board
  $board = $this->getBoard($board_id);

  if(isset($board['fk_i_parent_id']) && $board['fk_i_parent_id'] > 0) {
    $this->updateBoardStats($board['fk_i_parent_id'], $type, $value);
  }
}


// UPDATE TOPIC LAST POST DATE
public function updateTopicLastPostDate($topic_id) {
  $this->dao->query('UPDATE '.$this->getTable_topic().' SET dt_last_post_date = "' . date('Y-m-d H:i:s') . '" WHERE pk_i_id=' . $topic_id);
}


// UPDATE ID OF FIRST POST ON TOPIC
public function updateFirstPostId($topic_id, $post_id) {
  $this->dao->query('UPDATE '.$this->getTable_topic().' SET fk_i_first_post_id = ' . $post_id . ' WHERE pk_i_id=' . $topic_id);
}


// UPDATE TOPIC LAST POST DATE
public function updateTopicLastUser($topic_id, $user_id) {
  $this->dao->query('UPDATE '.$this->getTable_topic().' SET fk_i_last_user_id = ' . $user_id . ' WHERE pk_i_id=' . $topic_id);
}


// UPDATE TOPIC ACTIVE USERS IDS
public function updateTopicActiveUsers($list, $topic_id) {
  $this->dao->query('UPDATE '.$this->getTable_topic().' SET s_active_users_ids = "' . $list . '" WHERE pk_i_id=' . $topic_id);
}


// UPDATE USER STATS
public function updateUserStats($user_id, $type, $value) {
  if($type == 'topic') {
    $column = 'i_num_topics';
  } else {
    $column = 'i_num_posts';
  }

  $this->dao->query('UPDATE '.$this->getTable_user().' SET ' . $column . ' = coalesce(' . $column . ', 0) + (' . $value . ') WHERE fk_i_user_id=' . $user_id);
}


// UPDATE USER STATS
public function updateUserStatsGlobal($user_id, $data) {
  $this->dao->update($this->getTable_user(), $data, array('fk_i_user_id' => $user_id));
}


// UPDATE TOPIC STATS
public function updateTopicStatsGlobal($topic_id, $data) {
  $this->dao->update($this->getTable_topic(), $data, array('pk_i_id' => $topic_id));
}


// UPDATE BOARD STATS
public function updateBoardStatsGlobal($board_id, $data) {
  $this->dao->update($this->getTable_board(), $data, array('pk_i_id' => $board_id));
}


// UPDATE CATEGORY POSITION
public function updateCategoryPosition($category_id, $order) {
  $this->dao->update($this->getTable_category(), array('i_order' => $order), array('pk_i_id' => $category_id));
}


// UPDATE ATTRIBUTE VALUE POSITION
public function updateBoardPosition($board_id, $parent_board_id, $order) {
  if($parent_id <= 0 || $parent_id == '' || !$parent_id) {
    $parent_id = null;
  }

  $this->dao->update($this->getTable_board(), array('fk_i_parent_id' => $parent_board_id, 'i_order' => $order), array('pk_i_id' => $board_id));
}


// UPDATE USER
public function updateUserData($id, $data) {
  $user = $this->getUser($id);

  if(!isset($user['fk_i_user_id']) || $user['fk_i_user_id'] <= 0) {
    $this->insertUser($id);
  }

  $this->dao->update($this->getTable_user(), $data, array('fk_i_user_id' => $id));
}



// GET STAT TOPICS
public function getStatTopics() {
  $this->dao->select('pk_i_id');
  $this->dao->from($this->getTable_topic());

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}


// GET STAT BOARDS
public function getStatBoards() {
  $this->dao->select('pk_i_id, fk_i_parent_id');
  $this->dao->from($this->getTable_board());

  $result = $this->dao->get();
  
  if($result) {
    $data = $result->result();
    return $data;
  }

  return array();
}

}
?>