SET FOREIGN_KEY_CHECKS=0;


DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_category;
CREATE TABLE /*TABLE_PREFIX*/t_frm_category (
  pk_i_id INT NOT NULL AUTO_INCREMENT,
  i_order INT DEFAULT 0,
  
  PRIMARY KEY (pk_i_id)
) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';


DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_category_locale;
CREATE TABLE /*TABLE_PREFIX*/t_frm_category_locale (
  fk_i_category_id INT NOT NULL,
  fk_c_locale_code CHAR(5) NOT NULL,
  s_name VARCHAR(100) NOT NULL,
  
  PRIMARY KEY (fk_i_category_id, fk_c_locale_code),
  FOREIGN KEY (fk_i_category_id) REFERENCES /*TABLE_PREFIX*/t_frm_category (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE

) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';

  
DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_board;
CREATE TABLE /*TABLE_PREFIX*/t_frm_board (
  pk_i_id INT NOT NULL AUTO_INCREMENT,
  fk_i_category_id INT NOT NULL,
  fk_i_parent_id INT NULL,
  i_num_topics INT DEFAULT 0,
  i_num_posts INT DEFAULT 0,
  fk_i_last_topic_id INT NULL,
  fk_i_last_user_id INT NULL,
  dt_last_post_date TIMESTAMP NULL,
  s_premium_groups_ids VARCHAR(200) NULL,
  s_moderators_ids VARCHAR(200) NULL,
  i_order INT DEFAULT 0,
  
  PRIMARY KEY (pk_i_id),
  FOREIGN KEY (fk_i_category_id) REFERENCES /*TABLE_PREFIX*/t_frm_category (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE

) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';

  
DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_board_locale;
CREATE TABLE /*TABLE_PREFIX*/t_frm_board_locale (
  fk_i_board_id INT NOT NULL,
  fk_c_locale_code CHAR(5) NOT NULL,
  s_name VARCHAR(100) NOT NULL,
  s_description VARCHAR(500) NULL,
  
  PRIMARY KEY (fk_i_board_id, fk_c_locale_code),
  FOREIGN KEY (fk_i_board_id) REFERENCES /*TABLE_PREFIX*/t_frm_board (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE

) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';

  
DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_topic;
CREATE TABLE /*TABLE_PREFIX*/t_frm_topic (
  pk_i_id INT NOT NULL AUTO_INCREMENT,
  fk_i_board_id INT NOT NULL,
  fk_i_user_id INT NOT NULL,
  s_title VARCHAR(100),
  b_solved BOOLEAN NULL,
  fk_i_solved_by INT NULL,
  dt_solved_date TIMESTAMP NULL,
  b_locked BOOLEAN NULL,
  fk_i_locked_by INT NULL,
  dt_locked_date TIMESTAMP NULL,
  b_sticky BOOLEAN NULL,
  i_num_posts INT DEFAULT 0,
  i_num_views INT DEFAULT 0,
  s_active_users_ids VARCHAR(1000) NULL,
  fk_i_answer_post_id INT NULL,
  fk_i_last_post_id INT NULL,
  fk_i_last_user_id INT NULL,
  fk_i_first_post_id INT NULL,
  dt_last_post_date TIMESTAMP NULL,
  dt_created TIMESTAMP NULL,
  
  PRIMARY KEY (pk_i_id),
  FOREIGN KEY (fk_i_board_id) REFERENCES /*TABLE_PREFIX*/t_frm_board (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE

) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';


DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_post;
CREATE TABLE /*TABLE_PREFIX*/t_frm_post (
  pk_i_id INT NOT NULL AUTO_INCREMENT,
  fk_i_topic_id INT NOT NULL,
  fk_i_board_id INT NOT NULL,
  fk_i_user_id INT NOT NULL,
  s_body MEDIUMTEXT,
  s_file VARCHAR(100),
  fk_i_modified_by INT NULL,
  dt_modified_date TIMESTAMP NULL,
  dt_created TIMESTAMP NULL,
  
  PRIMARY KEY (pk_i_id),
  FOREIGN KEY (fk_i_topic_id) REFERENCES /*TABLE_PREFIX*/t_frm_topic (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (fk_i_board_id) REFERENCES /*TABLE_PREFIX*/t_frm_board (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE

) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';


DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_user;
CREATE TABLE /*TABLE_PREFIX*/t_frm_user (
  fk_i_user_id INT NOT NULL,
  s_username VARCHAR(50) NULL,
  s_image VARCHAR(100) NULL,
  s_motto VARCHAR(100) NULL,
  s_title VARCHAR(100) NULL,
  s_website VARCHAR(100) NULL,
  s_signature VARCHAR(100) NULL,
  b_moderator BOOLEAN NULL,
  b_admin BOOLEAN NULL,
  i_num_topics INT DEFAULT 0,
  i_num_posts INT DEFAULT 0,
  dt_last_active TIMESTAMP NULL,
  dt_registered TIMESTAMP,
  
  PRIMARY KEY (fk_i_user_id)
) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';


DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_board_read;
CREATE TABLE /*TABLE_PREFIX*/t_frm_board_read (
  fk_i_user_id INT NOT NULL,
  fk_i_board_id INT NOT NULL,
  i_viewed INT DEFAULT 0,
  
  PRIMARY KEY (fk_i_user_id, fk_i_board_id),
  FOREIGN KEY (fk_i_board_id) REFERENCES /*TABLE_PREFIX*/t_frm_board (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE

) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';


DROP TABLE IF EXISTS /*TABLE_PREFIX*/t_frm_topic_read;
CREATE TABLE /*TABLE_PREFIX*/t_frm_topic_read (
  fk_i_user_id INT NOT NULL,
  fk_i_board_id INT NOT NULL,
  fk_i_topic_id INT NOT NULL,
  i_viewed INT DEFAULT 0,
  
  PRIMARY KEY (fk_i_user_id, fk_i_board_id, fk_i_topic_id),
  FOREIGN KEY (fk_i_topic_id) REFERENCES /*TABLE_PREFIX*/t_frm_topic (pk_i_id) ON DELETE CASCADE ON UPDATE CASCADE

) ENGINE=InnoDB DEFAULT CHARACTER SET 'UTF8' COLLATE 'UTF8_GENERAL_CI';


INSERT INTO /*TABLE_PREFIX*/t_frm_user (fk_i_user_id, s_username, dt_registered) SELECT pk_i_id, s_name, dt_reg_date FROM /*TABLE_PREFIX*/t_user;

SET FOREIGN_KEY_CHECKS=1;
