<?php
// MAKE SURE OSC_PLUGIN_PATH FUNCTION EXISTS
if( !function_exists('osc_plugin_path') ) {
  function osc_plugin_path($file) {
    $file = preg_replace('|/+|','/', str_replace('\\','/',$file));
    $plugin_path = preg_replace('|/+|','/', str_replace('\\','/', PLUGINS_PATH));
    $file = $plugin_path . preg_replace('#^.*oc-content\/plugins\/#','',$file);
    return $file;
  }
}



// GENERATE SITEMAP
function frm_generate_sitemap() {
  $start_time = microtime(true);

  $categories = ModelFRM::newInstance()->getCategories();
  $users = ModelFRM::newInstance()->getForumUsers();

  
  $locales = osc_get_locales();

  $filename = osc_base_path() . 'sitemap_forums.xml';
  @unlink($filename); 
  
  $start_xml = '<?xml version="1.0" encoding="UTF-8"?>' . PHP_EOL . '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">' . PHP_EOL;
  file_put_contents($filename, $start_xml);


  // INDEX
  frm_sitemap_add_url(osc_route_url('frm-home'), date('Y-m-d'), 'always');


  // ADD CATEGORIES
  if(count($categories) > 0) {
    foreach($categories as $c) {
      $boards = ModelFRM::newInstance()->getBoards($c['pk_i_id']);

      if(count($boards) > 0) { 
        foreach($boards as $b) {
          frm_sitemap_add_url(frm_board_url($b), date('Y-m-d'), 'daily');

          $topics = ModelFRM::newInstance()->getTopics($b['pk_i_id']);

          if(count($topics) > 0) {
            foreach($topics as $t) {
              frm_sitemap_add_url(frm_topic_url($t), date('Y-m-d'), 'hourly');
            }
          } 
        }
      }
    }
  }

  // ADD AUTHORS
  if(count($users) > 0) {
    foreach($users as $u) {
      if(frm_user_url($u) <> '#') {
        frm_sitemap_add_url(frm_user_url($u), date('Y-m-d'), 'daily');
      }
    }
  }


  $end_xml = '</urlset>';
  file_put_contents($filename, $end_xml, FILE_APPEND);
  

  // PING SEARCH ENGINES
  frm_sitemap_ping_engines();
  
  // CALCULATE GENERATION TIME
  $time_elapsed = microtime(true) - $start_time;
  return $time_elapsed;
}



// ADD URL TO SITEMAP - HELP FUNCTION
function frm_sitemap_add_url($url = '', $date = '', $freq = 'daily') {
  if( preg_match('|\?(.*)|', $url, $match) ) {
    $sub_url = $match[1];
    $param = explode('&', $sub_url);
    foreach($param as &$p) {
      list($key, $value) = explode('=', $p);
      $p = $key . '=' . urlencode($value);
    }
    $sub_url = implode('&', $param);
    $url = preg_replace('|\?.*|', '?' . $sub_url, $url);
  } else {
    $help = $url; 
    $help_encode = urlencode($help);
    $help_fix = str_replace('%2C', ',', $help_encode);
    $help_fix = str_replace('%2F', '/', $help_fix);
    $help_fix = str_replace('%3A', ':', $help_fix);
    $url = $help_fix;     
  }

  $filename = osc_base_path() . 'sitemap_forums.xml';
  $xml  = '  <url>' . PHP_EOL;
  $xml .= '    <loc>' . htmlentities($url, ENT_QUOTES, "UTF-8") . '</loc>' . PHP_EOL;
  $xml .= '    <lastmod>' . $date . '</lastmod>' . PHP_EOL;
  $xml .= '    <changefreq>' . $freq . '</changefreq>' . PHP_EOL;
  $xml .= '  </url>' . PHP_EOL;
  file_put_contents($filename, $xml, FILE_APPEND);
}



// PING SEARCH ENGINES WITH NEW SITEMAP - HELP FUNCTION
function frm_sitemap_ping_engines() {
  $sitemap = osc_base_url() . 'sitemap_forums.xml';

  osc_doRequest( 'http://www.google.com/webmasters/sitemaps/ping?sitemap='.urlencode($sitemap), array());
  osc_doRequest( 'http://www.bing.com/webmaster/ping.aspx?siteMap='.urlencode($sitemap), array());
  //osc_doRequest( 'http://search.yahooapis.com/SiteExplorerService/V1/updateNotification?appid='.osc_page_title().'&url='.urlencode($sitemap), array());
}



osc_add_hook('cron_daily', 'frm_generate_sitemap');

?>